@@ -22,13 +22,11 @@ import uuid
 
 from decorator import decorator
 import jmespath
-import munch
 import netifaces
 import sre_constants
 
 from openstack import _log
 from openstack.cloud import exc
-from openstack.cloud import meta
 
 
 _decorated_methods = []
@@ -37,8 +35,7 @@ _decorated_methods = []
 def _make_unicode(input):
     """Turn an input into unicode unconditionally
 
-    :param input:
-       A unicode, string or other object
+    :param input: A unicode, string or other object
     """
     try:
         if isinstance(input, unicode):
@@ -66,24 +63,23 @@ def _dictify_resource(resource):
 def _filter_list(data, name_or_id, filters):
     """Filter a list by name/ID and arbitrary meta data.
 
-    :param list data:
-        The list of dictionary data to filter. It is expected that
-        each dictionary contains an 'id' and 'name'
-        key if a value for name_or_id is given.
-    :param string name_or_id:
-        The name or ID of the entity being filtered. Can be a glob pattern,
-        such as 'nb01*'.
-    :param filters:
-        A dictionary of meta data to use for further filtering. Elements
-        of this dictionary may, themselves, be dictionaries. Example::
+    :param list data: The list of dictionary data to filter. It is expected
+        that each dictionary contains an 'id' and 'name' key if a value for
+        name_or_id is given.
+    :param string name_or_id: The name or ID of the entity being filtered. Can
+        be a glob pattern, such as 'nb01*'.
+    :param filters: A dictionary of meta data to use for further filtering.
+        Elements of this dictionary may, themselves, be dictionaries. Example::
 
             {
-              'last_name': 'Smith',
-              'other': {
-                  'gender': 'Female'
-              }
+                'last_name': 'Smith',
+                'other': {
+                    'gender': 'Female'
+                }
             }
+
         OR
+
         A string containing a jmespath expression for further filtering.
     """
     # The logger is openstack.cloud.fmmatch to allow a user/operator to
@@ -158,20 +154,16 @@ def _filter_list(data, name_or_id, filters):
 def _get_entity(cloud, resource, name_or_id, filters, **kwargs):
     """Return a single entity from the list returned by a given method.
 
-    :param object cloud:
-        The controller class (Example: the main OpenStackCloud object) .
-    :param string or callable resource:
-        The string that identifies the resource to use to lookup the
-        get_<>_by_id or search_<resource>s methods(Example: network)
-        or a callable to invoke.
-    :param string name_or_id:
-        The name or ID of the entity being filtered or an object or dict.
-        If this is an object/dict with an 'id' attr/key, we return it and
-        bypass resource lookup.
-    :param filters:
-        A dictionary of meta data to use for further filtering.
-        OR
-        A string containing a jmespath expression for further filtering.
+    :param object cloud: The controller class (Example: the main OpenStackCloud
+        object).
+    :param string or callable resource: The string that identifies the resource
+        to use to lookup the get_<>_by_id or search_<resource>s methods
+        (Example: network) or a callable to invoke.
+    :param string name_or_id: The name or ID of the entity being filtered or an
+        object or dict. If this is an object/dict with an 'id' attr/key, we
+        return it and bypass resource lookup.
+    :param filters: A dictionary of meta data to use for further filtering.
+        OR A string containing a jmespath expression for further filtering.
         Example:: "[?last_name==`Smith`] | [?other.gender]==`Female`]"
     """
 
@@ -204,31 +196,6 @@ def _get_entity(cloud, resource, name_or_id, filters, **kwargs):
     return None
 
 
-def normalize_keystone_services(services):
-    """Normalize the structure of keystone services
-
-    In keystone v2, there is a field called "service_type". In v3, it's
-    "type". Just make the returned dict have both.
-
-    :param list services: A list of keystone service dicts
-
-    :returns: A list of normalized dicts.
-    """
-    ret = []
-    for service in services:
-        service_type = service.get('type', service.get('service_type'))
-        new_service = {
-            'id': service['id'],
-            'name': service['name'],
-            'description': service.get('description', None),
-            'type': service_type,
-            'service_type': service_type,
-            'enabled': service['enabled']
-        }
-        ret.append(new_service)
-    return meta.obj_list_to_munch(ret)
-
-
 def localhost_supports_ipv6():
     """Determine whether the local host supports IPv6
 
@@ -243,109 +210,6 @@ def localhost_supports_ipv6():
         return False
 
 
-def normalize_users(users):
-    ret = [
-        dict(
-            id=user.get('id'),
-            email=user.get('email'),
-            name=user.get('name'),
-            username=user.get('username'),
-            default_project_id=user.get('default_project_id',
-                                        user.get('tenantId')),
-            domain_id=user.get('domain_id'),
-            enabled=user.get('enabled'),
-            description=user.get('description')
-        ) for user in users
-    ]
-    return meta.obj_list_to_munch(ret)
-
-
-def normalize_domains(domains):
-    ret = [
-        dict(
-            id=domain.get('id'),
-            name=domain.get('name'),
-            description=domain.get('description'),
-            enabled=domain.get('enabled'),
-        ) for domain in domains
-    ]
-    return meta.obj_list_to_munch(ret)
-
-
-def normalize_groups(domains):
-    """Normalize Identity groups."""
-    ret = [
-        dict(
-            id=domain.get('id'),
-            name=domain.get('name'),
-            description=domain.get('description'),
-            domain_id=domain.get('domain_id'),
-        ) for domain in domains
-    ]
-    return meta.obj_list_to_munch(ret)
-
-
-def normalize_role_assignments(assignments):
-    """Put role_assignments into a form that works with search/get interface.
-
-    Role assignments have the structure::
-
-        [
-            {
-                "role": {
-                    "id": "--role-id--"
-                },
-                "scope": {
-                    "domain": {
-                        "id": "--domain-id--"
-                    }
-                },
-                "user": {
-                    "id": "--user-id--"
-                }
-            },
-        ]
-
-    Which is hard to work with in the rest of our interface. Map this to be::
-
-        [
-            {
-                "id": "--role-id--",
-                "domain": "--domain-id--",
-                "user": "--user-id--",
-            }
-        ]
-
-    Scope can be "domain" or "project" and "user" can also be "group".
-
-    :param list assignments: A list of dictionaries of role assignments.
-
-    :returns: A list of flattened/normalized role assignment dicts.
-    """
-    new_assignments = []
-    for assignment in assignments:
-        new_val = munch.Munch({'id': assignment['role']['id']})
-        for scope in ('project', 'domain'):
-            if scope in assignment['scope']:
-                new_val[scope] = assignment['scope'][scope]['id']
-        for assignee in ('user', 'group'):
-            if assignee in assignment:
-                new_val[assignee] = assignment[assignee]['id']
-        new_assignments.append(new_val)
-    return new_assignments
-
-
-def normalize_flavor_accesses(flavor_accesses):
-    """Normalize Flavor access list."""
-    return [munch.Munch(
-        dict(
-            flavor_id=acl.get('flavor_id'),
-            project_id=acl.get('project_id') or acl.get('tenant_id'),
-        )
-    ) for acl in flavor_accesses
-    ]
-
-
 def valid_kwargs(*valid_args):
     # This decorator checks if argument passed as **kwargs to a function are
     # present in valid_args.
@@ -414,13 +278,13 @@ def shade_exceptions(error_message=None):
     :param string error_message: String to use for the exception message
         content on non-OpenStackCloudExceptions.
 
-    Useful for avoiding wrapping shade OpenStackCloudException exceptions
-    within themselves. Code called from within the context may throw such
-    exceptions without having to catch and reraise them.
+        Useful for avoiding wrapping shade OpenStackCloudException exceptions
+        within themselves. Code called from within the context may throw such
+        exceptions without having to catch and reraise them.
 
-    Non-OpenStackCloudException exceptions thrown within the context will
-    be wrapped and the exception message will be appended to the given error
-    message.
+        Non-OpenStackCloudException exceptions thrown within the context will
+        be wrapped and the exception message will be appended to the given
+        error message.
     """
     try:
         yield
@@ -506,16 +370,15 @@ def _call_client_and_retry(client, url, retry_on=None,
     the ability to retry upon known error codes.
 
     :param object client: The client method, such as:
-                          ``self.baremetal_client.post``
+        ``self.baremetal_client.post``
     :param string url: The URL to perform the operation upon.
     :param integer retry_on: A list of error codes that can be retried on.
-                             The method also supports a single integer to be
-                             defined.
+        The method also supports a single integer to be
+        defined.
     :param integer call_retries: The number of times to retry the call upon
-                                 the error code defined by the 'retry_on'
-                                 parameter. Default: 3
+        the error code defined by the 'retry_on' parameter. Default: 3
     :param integer retry_wait: The time in seconds to wait between retry
-                               attempts. Default: 2
+        attempts. Default: 2
 
     :returns: The object returned by the client call.
     """
