@@ -87,7 +87,7 @@ class HttpException(SDKException, _rex.HTTPError):
         if self.status_code is not None and (400 <= self.status_code < 500):
             self.source = "Client"
 
-    def __unicode__(self):
+    def __str__(self):
         # 'Error' is the default value for self.message. If self.message isn't
         # 'Error', then someone has set a more informative error message
         # and we should use it. If it is 'Error', then we should construct a
@@ -106,9 +106,6 @@ class HttpException(SDKException, _rex.HTTPError):
             message=super(HttpException, self).__str__(),
             remote_error=remote_error)
 
-    def __str__(self):
-        return self.__unicode__()
-
 
 class BadRequestException(HttpException):
     """HTTP 400 Bad Request."""
@@ -211,6 +208,9 @@ def raise_from_response(response, error_message=None):
         try:
             content = response.json()
             messages = [_extract_message(obj) for obj in content.values()]
+            if not any(messages):
+                # Exception dict may be the root dict in projects that use WSME
+                messages = [_extract_message(content)]
             # Join all of the messages together nicely and filter out any
             # objects that don't have a "message" attr.
             details = '\n'.join(msg for msg in messages if msg)
