@@ -9,13 +9,14 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from openstack.common import tag
 from openstack import exceptions
 from openstack.image import _download
 from openstack import resource
 from openstack import utils
 
 
-class Image(resource.Resource, resource.TagMixin, _download.DownloadMixin):
+class Image(resource.Resource, tag.TagMixin, _download.DownloadMixin):
     resources_key = 'images'
     base_path = '/images'
 
@@ -33,13 +34,24 @@ class Image(resource.Resource, resource.TagMixin, _download.DownloadMixin):
     _store_unknown_attrs_as_properties = True
 
     _query_mapping = resource.QueryParameters(
-        "name", "visibility",
-        "member_status", "owner",
-        "status", "size_min", "size_max",
-        "protected", "is_hidden",
-        "sort_key", "sort_dir", "sort", "tag",
-        "created_at", "updated_at",
-        is_hidden="os_hidden")
+        "id",
+        "name",
+        "visibility",
+        "member_status",
+        "owner",
+        "status",
+        "size_min",
+        "size_max",
+        "protected",
+        "is_hidden",
+        "sort_key",
+        "sort_dir",
+        "sort",
+        "tag",
+        "created_at",
+        "updated_at",
+        is_hidden="os_hidden",
+    )
 
     # NOTE: Do not add "self" support here. If you've used Python before,
     # you know that self, while not being a reserved word, has special
@@ -224,8 +236,9 @@ class Image(resource.Resource, resource.TagMixin, _download.DownloadMixin):
     os_type = resource.Body('os_type')
     #: The operating system admin username.
     os_admin_user = resource.Body('os_admin_user')
-    #: If true, QEMU guest agent will be exposed to the instance.
-    hw_qemu_guest_agent = resource.Body('hw_qemu_guest_agent', type=bool)
+    #: A string boolean, which if "true", QEMU guest agent will be exposed
+    #: to the instance.
+    hw_qemu_guest_agent = resource.Body('hw_qemu_guest_agent', type=str)
     #: If true, require quiesce on snapshot via QEMU guest agent.
     os_require_quiesce = resource.Body('os_require_quiesce', type=bool)
     #: The URL for the schema describing a virtual machine image.
