@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.network import network_service
 from openstack import resource as _resource
 
 
@@ -18,20 +17,26 @@ class AvailabilityZone(_resource.Resource):
     resource_key = 'availability_zone'
     resources_key = 'availability_zones'
     base_path = '/availability_zones'
-    service = network_service.NetworkService()
+
+    _allow_unknown_attrs_in_body = True
 
     # capabilities
     allow_create = False
-    allow_retrieve = False
-    allow_update = False
+    allow_fetch = False
+    allow_commit = False
     allow_delete = False
     allow_list = True
 
+    # NOTE: We don't support query by state yet because there is a mapping
+    #       at neutron side difficult to map.
+    _query_mapping = _resource.QueryParameters(
+        name='availability_zone', resource='agent_type')
+
     # Properties
     #: Name of the availability zone.
-    name = _resource.prop('name')
+    name = _resource.Body('name')
     #: Type of resource for the availability zone, such as ``network``.
-    resource = _resource.prop('resource')
+    resource = _resource.Body('resource')
     #: State of the availability zone, either ``available`` or
     #: ``unavailable``.
-    state = _resource.prop('state')
+    state = _resource.Body('state')
