@@ -9,9 +9,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
-from openstack.network import network_service
-from openstack.network.v2 import tag
+from openstack.common import tag
 from openstack import resource
 
 
@@ -19,20 +17,20 @@ class SubnetPool(resource.Resource, tag.TagMixin):
     resource_key = 'subnetpool'
     resources_key = 'subnetpools'
     base_path = '/subnetpools'
-    service = network_service.NetworkService()
+
+    _allow_unknown_attrs_in_body = True
 
     # capabilities
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
     _query_mapping = resource.QueryParameters(
         'address_scope_id', 'description', 'ip_version', 'is_default',
-        'name',
+        'name', 'project_id',
         is_shared='shared',
-        project_id='tenant_id',
         **tag.TagMixin._tag_query_parameters
     )
 
@@ -70,7 +68,9 @@ class SubnetPool(resource.Resource, tag.TagMixin):
     #: The subnet pool name.
     name = resource.Body('name')
     #: The ID of the project that owns the subnet pool.
-    project_id = resource.Body('tenant_id')
+    project_id = resource.Body('project_id', alias='tenant_id')
+    #: Tenant_id (deprecated attribute).
+    tenant_id = resource.Body('tenant_id', deprecated=True)
     #: A list of subnet prefixes that are assigned to the subnet pool.
     #: The adjacent prefixes are merged and treated as a single prefix.
     #: *Type: list*
