@@ -19,14 +19,15 @@ import os
 import time
 from urllib import parse
 
+from openstack import _log
+from openstack.cloud import _utils
+from openstack import exceptions
 from openstack.object_store.v1 import account as _account
 from openstack.object_store.v1 import container as _container
-from openstack.object_store.v1 import obj as _obj
 from openstack.object_store.v1 import info as _info
-from openstack import exceptions
-from openstack import _log
+from openstack.object_store.v1 import obj as _obj
 from openstack import proxy
-from openstack.cloud import _utils
+from openstack import utils
 
 DEFAULT_OBJECT_SEGMENT_SIZE = 1073741824  # 1GB
 DEFAULT_MAX_FILE_SIZE = (5 * 1024 * 1024 * 1024 + 2) / 2
@@ -94,10 +95,9 @@ class Proxy(proxy.Proxy):
     def set_account_metadata(self, **metadata):
         """Set metadata for this account.
 
-        :param kwargs metadata: Key/value pairs to be set as metadata
-                                on the container. Custom  metadata can be set.
-                                Custom metadata are keys and values defined
-                                by the user.
+        :param kwargs metadata: Key/value pairs to be set as metadata on the
+            container. Custom metadata can be set. Custom metadata are keys and
+            values defined by the user.
         """
         account = self._get_resource(_account.Account, None)
         account.set_metadata(self, metadata)
@@ -114,7 +114,7 @@ class Proxy(proxy.Proxy):
         """Obtain Container objects for this account.
 
         :param kwargs query: Optional query parameters to be sent to limit
-                                 the resources being returned.
+            the resources being returned.
 
         :rtype: A generator of
             :class:`~openstack.object_store.v1.container.Container` objects.
@@ -126,8 +126,8 @@ class Proxy(proxy.Proxy):
 
         :param container: Name of the container to create.
         :param dict attrs: Keyword arguments which will be used to create
-               a :class:`~openstack.object_store.v1.container.Container`,
-               comprised of the properties on the Container class.
+            a :class:`~openstack.object_store.v1.container.Container`,
+            comprised of the properties on the Container class.
 
         :returns: The results of container creation
         :rtype: :class:`~openstack.object_store.v1.container.Container`
@@ -138,13 +138,11 @@ class Proxy(proxy.Proxy):
         """Delete a container
 
         :param container: The value can be either the name of a container or a
-                      :class:`~openstack.object_store.v1.container.Container`
-                      instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
         :param bool ignore_missing: When set to ``False``
-                    :class:`~openstack.exceptions.ResourceNotFound` will be
-                    raised when the container does not exist.
-                    When set to ``True``, no exception will be set when
-                    attempting to delete a nonexistent server.
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the container does not exist. When set to ``True``, no exception
+            will be set when attempting to delete a nonexistent server.
 
         :returns: ``None``
         """
@@ -155,12 +153,11 @@ class Proxy(proxy.Proxy):
         """Get metadata for a container
 
         :param container: The value can be the name of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
 
         :returns: One :class:`~openstack.object_store.v1.container.Container`
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                 when no resource can be found.
+            when no resource can be found.
         """
         return self._head(_container.Container, container)
 
@@ -168,24 +165,22 @@ class Proxy(proxy.Proxy):
         """Set metadata for a container.
 
         :param container: The value can be the name of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container`
+            instance.
         :param refresh: Flag to trigger refresh of container object re-fetch.
-        :param kwargs metadata: Key/value pairs to be set as metadata
-                                on the container. Both custom and system
-                                metadata can be set. Custom metadata are keys
-                                and values defined by the user. System
-                                metadata are keys defined by the Object Store
-                                and values defined by the user. The system
-                                metadata keys are:
+        :param kwargs metadata: Key/value pairs to be set as metadata on the
+            container. Both custom and system metadata can be set. Custom
+            metadata are keys and values defined by the user. System metadata
+            are keys defined by the Object Store and values defined by the
+            user. The system metadata keys are:
 
-                                - `content_type`
-                                - `is_content_type_detected`
-                                - `versions_location`
-                                - `read_ACL`
-                                - `write_ACL`
-                                - `sync_to`
-                                - `sync_key`
+            - `content_type`
+            - `is_content_type_detected`
+            - `versions_location`
+            - `read_ACL`
+            - `write_ACL`
+            - `sync_to`
+            - `sync_key`
         """
         res = self._get_resource(_container.Container, container)
         res.set_metadata(self, metadata, refresh=refresh)
@@ -195,8 +190,7 @@ class Proxy(proxy.Proxy):
         """Delete metadata for a container.
 
         :param container: The value can be the ID of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
         :param keys: The keys of metadata to be deleted.
         """
         res = self._get_resource(_container.Container, container)
@@ -211,7 +205,7 @@ class Proxy(proxy.Proxy):
         :type container:
             :class:`~openstack.object_store.v1.container.Container`
         :param kwargs query: Optional query parameters to be sent to limit
-                                 the resources being returned.
+            the resources being returned.
 
         :rtype: A generator of
             :class:`~openstack.object_store.v1.obj.Object` objects.
@@ -235,36 +229,78 @@ class Proxy(proxy.Proxy):
 
         raise ValueError("container must be specified")
 
-    def get_object(self, obj, container=None):
+    def get_object(
+        self, obj, container=None, resp_chunk_size=1024,
+        outfile=None, remember_content=False
+    ):
         """Get the data associated with an object
 
         :param obj: The value can be the name of an object or a
-                       :class:`~openstack.object_store.v1.obj.Object` instance.
+            :class:`~openstack.object_store.v1.obj.Object` instance.
         :param container: The value can be the name of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
+        :param int resp_chunk_size: chunk size of data to read. Only used if
+            the results are being written to a file or stream is True.
+            (optional, defaults to 1k)
+        :param outfile: Write the object to a file instead of returning the
+            contents. If this option is given, body in the return tuple will be
+            None. outfile can either be a file path given as a string, or a
+            File like object.
+        :param bool remember_content: Flag whether object data should be saved
+            as `data` property of the Object. When left as `false` and
+            `outfile` is not defined data will not be saved and need to be
+            fetched separately.
 
-        :returns: The contents of the object.  Use the
-                  :func:`~get_object_metadata`
-                  method if you want an object resource.
+        :returns: Instance of the
+            :class:`~openstack.object_store.v1.obj.Object` objects.
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                 when no resource can be found.
+            when no resource can be found.
         """
         container_name = self._get_container_name(
             obj=obj, container=container)
-        return self._get(_obj.Object, obj, container=container_name)
+
+        _object = self._get_resource(
+            _obj.Object, obj,
+            container=container_name)
+        request = _object._prepare_request()
+
+        get_stream = (outfile is not None)
+
+        response = self.get(
+            request.url,
+            headers=request.headers,
+            stream=get_stream
+        )
+        exceptions.raise_from_response(response)
+        _object._translate_response(response, has_body=False)
+
+        if outfile:
+            if isinstance(outfile, str):
+                outfile_handle = open(outfile, 'wb')
+            else:
+                outfile_handle = outfile
+            for chunk in response.iter_content(
+                    resp_chunk_size, decode_unicode=False):
+                outfile_handle.write(chunk)
+            if isinstance(outfile, str):
+                outfile_handle.close()
+            else:
+                outfile_handle.flush()
+        elif remember_content:
+            _object.data = response.text
+
+        return _object
 
     def download_object(self, obj, container=None, **attrs):
         """Download the data contained inside an object.
 
         :param obj: The value can be the name of an object or a
-                       :class:`~openstack.object_store.v1.obj.Object` instance.
+            :class:`~openstack.object_store.v1.obj.Object` instance.
         :param container: The value can be the name of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
 
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                 when no resource can be found.
+            when no resource can be found.
         """
         container_name = self._get_container_name(
             obj=obj, container=container)
@@ -276,18 +312,16 @@ class Proxy(proxy.Proxy):
         """Stream the data contained inside an object.
 
         :param obj: The value can be the name of an object or a
-                       :class:`~openstack.object_store.v1.obj.Object` instance.
+            :class:`~openstack.object_store.v1.obj.Object` instance.
         :param container: The value can be the name of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
 
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                 when no resource can be found.
+            when no resource can be found.
         :returns: An iterator that iterates over chunk_size bytes
         """
         container_name = self._get_container_name(
             obj=obj, container=container)
-        container_name = self._get_container_name(container=container)
         obj = self._get_resource(
             _obj.Object, obj, container=container_name, **attrs)
         return obj.stream(self, chunk_size=chunk_size)
@@ -308,7 +342,7 @@ class Proxy(proxy.Proxy):
         :param filename: The path to the local file whose contents will be
             uploaded. Mutually exclusive with data.
         :param data: The content to upload to the object. Mutually exclusive
-           with filename.
+            with filename.
         :param md5: A hexadecimal md5 of the file. (Optional), if it is known
             and can be passed here, it will save repeating the expensive md5
             process. It is assumed to be accurate.
@@ -353,16 +387,11 @@ class Proxy(proxy.Proxy):
             filename = name
 
         if generate_checksums and (md5 is None or sha256 is None):
-            (md5, sha256) = self._connection._get_file_hashes(filename)
+            (md5, sha256) = utils._get_file_hashes(filename)
         if md5:
-            headers[self._connection._OBJECT_MD5_KEY] = md5 or ''
+            metadata[self._connection._OBJECT_MD5_KEY] = md5
         if sha256:
-            headers[self._connection._OBJECT_SHA256_KEY] = sha256 or ''
-        for (k, v) in metadata.items():
-            if not k.lower().startswith('x-object-meta-'):
-                headers['x-object-meta-' + k] = v
-            else:
-                headers[k] = v
+            metadata[self._connection._OBJECT_SHA256_KEY] = sha256
 
         container_name = self._get_container_name(container=container)
         endpoint = '{container}/{name}'.format(container=container_name,
@@ -372,10 +401,10 @@ class Proxy(proxy.Proxy):
             self.log.debug(
                 "swift uploading data to %(endpoint)s",
                 {'endpoint': endpoint})
-            # TODO(gtema): custom headers need to be somehow injected
             return self._create(
                 _obj.Object, container=container_name,
-                name=name, data=data, **headers)
+                name=name, data=data, metadata=metadata,
+                **headers)
 
         # segment_size gets used as a step value in a range call, so needs
         # to be an int
@@ -390,10 +419,14 @@ class Proxy(proxy.Proxy):
                 "swift uploading %(filename)s to %(endpoint)s",
                 {'filename': filename, 'endpoint': endpoint})
 
+            if metadata is not None:
+                # Rely on the class headers calculation for requested metadata
+                meta_headers = _obj.Object()._calculate_headers(metadata)
+                headers.update(meta_headers)
+
             if file_size <= segment_size:
-                # TODO(gtema): replace with regular resource put, but
-                # custom headers need to be somehow injected
                 self._upload_object(endpoint, filename, headers)
+
             else:
                 self._upload_large_object(
                     endpoint, filename, headers,
@@ -410,16 +443,13 @@ class Proxy(proxy.Proxy):
         """Delete an object
 
         :param obj: The value can be either the name of an object or a
-                       :class:`~openstack.object_store.v1.container.Container`
-                       instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
         :param container: The value can be the ID of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
         :param bool ignore_missing: When set to ``False``
-                    :class:`~openstack.exceptions.ResourceNotFound` will be
-                    raised when the object does not exist.
-                    When set to ``True``, no exception will be set when
-                    attempting to delete a nonexistent server.
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the object does not exist.  When set to ``True``, no exception will
+            be set when attempting to delete a nonexistent server.
 
         :returns: ``None``
         """
@@ -432,14 +462,13 @@ class Proxy(proxy.Proxy):
         """Get metadata for an object.
 
         :param obj: The value can be the name of an object or a
-                    :class:`~openstack.object_store.v1.obj.Object` instance.
+            :class:`~openstack.object_store.v1.obj.Object` instance.
         :param container: The value can be the ID of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
 
         :returns: One :class:`~openstack.object_store.v1.obj.Object`
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                 when no resource can be found.
+            when no resource can be found.
         """
         container_name = self._get_container_name(obj, container)
 
@@ -451,24 +480,21 @@ class Proxy(proxy.Proxy):
         Note: This method will do an extra HEAD call.
 
         :param obj: The value can be the name of an object or a
-                    :class:`~openstack.object_store.v1.obj.Object` instance.
+            :class:`~openstack.object_store.v1.obj.Object` instance.
         :param container: The value can be the name of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
         :param kwargs metadata: Key/value pairs to be set as metadata
-                                on the container. Both custom and system
-                                metadata can be set. Custom metadata are keys
-                                and values defined by the user. System
-                                metadata are keys defined by the Object Store
-                                and values defined by the user. The system
-                                metadata keys are:
+            on the container. Both custom and system metadata can be set.
+            Custom metadata are keys and values defined by the user. System
+            metadata are keys defined by the Object Store and values defined by
+            the user. The system metadata keys are:
 
-                                - `content_type`
-                                - `content_encoding`
-                                - `content_disposition`
-                                - `delete_after`
-                                - `delete_at`
-                                - `is_content_type_detected`
+            - `content_type`
+            - `content_encoding`
+            - `content_disposition`
+            - `delete_after`
+            - `delete_at`
+            - `is_content_type_detected`
         """
         container_name = self._get_container_name(obj, container)
         res = self._get_resource(_obj.Object, obj, container=container_name)
@@ -479,10 +505,9 @@ class Proxy(proxy.Proxy):
         """Delete metadata for an object.
 
         :param obj: The value can be the name of an object or a
-                    :class:`~openstack.object_store.v1.obj.Object` instance.
+            :class:`~openstack.object_store.v1.obj.Object` instance.
         :param container: The value can be the ID of a container or a
-               :class:`~openstack.object_store.v1.container.Container`
-               instance.
+            :class:`~openstack.object_store.v1.container.Container` instance.
         :param keys: The keys of metadata to be deleted.
         """
         container_name = self._get_container_name(obj, container)
@@ -497,15 +522,14 @@ class Proxy(proxy.Proxy):
         :param container: Name of the container.
         :param name: Name of the object.
         :param filename: Path to the file.
-        :param file_md5:
-            Pre-calculated md5 of the file contents. Defaults to None which
-            means calculate locally.
-        :param file_sha256:
-            Pre-calculated sha256 of the file contents. Defaults to None which
-            means calculate locally.
+        :param file_md5: Pre-calculated md5 of the file contents. Defaults to
+            None which means calculate locally.
+        :param file_sha256: Pre-calculated sha256 of the file contents.
+            Defaults to None which means calculate locally.
         """
-        metadata = self._connection.get_object_metadata(container, name)
-        if not metadata:
+        try:
+            metadata = self.get_object_metadata(name, container).metadata
+        except exceptions.NotFoundException:
             self._connection.log.debug(
                 "swift stale check, no object: {container}/{name}".format(
                     container=container, name=name))
@@ -513,14 +537,14 @@ class Proxy(proxy.Proxy):
 
         if not (file_md5 or file_sha256):
             (file_md5, file_sha256) = \
-                self._connection._get_file_hashes(filename)
+                utils._get_file_hashes(filename)
         md5_key = metadata.get(
             self._connection._OBJECT_MD5_KEY,
             metadata.get(self._connection._SHADE_OBJECT_MD5_KEY, ''))
         sha256_key = metadata.get(
             self._connection._OBJECT_SHA256_KEY, metadata.get(
                 self._connection._SHADE_OBJECT_SHA256_KEY, ''))
-        up_to_date = self._connection._hashes_up_to_date(
+        up_to_date = utils._hashes_up_to_date(
             md5=file_md5, sha256=file_sha256,
             md5_key=md5_key, sha256_key=sha256_key)
 
@@ -567,7 +591,10 @@ class Proxy(proxy.Proxy):
             # TODO(mordred) Collect etags from results to add to this manifest
             # dict. Then sort the list of dicts by path.
             manifest.append(dict(
-                path='/{name}'.format(name=name),
+                # While Object Storage usually expects the name to be
+                # urlencoded in most requests, the SLO manifest requires
+                # plain object names instead.
+                path='/{name}'.format(name=parse.unquote(name)),
                 size_bytes=segment.length))
 
         # Try once and collect failed results to retry
@@ -595,29 +622,61 @@ class Proxy(proxy.Proxy):
 
         self._add_etag_to_manifest(segment_results, manifest)
 
-        if use_slo:
-            return self._finish_large_object_slo(endpoint, headers, manifest)
-        else:
-            return self._finish_large_object_dlo(endpoint, headers)
+        try:
+            if use_slo:
+                return self._finish_large_object_slo(
+                    endpoint, headers, manifest)
+            else:
+                return self._finish_large_object_dlo(
+                    endpoint, headers)
+        except Exception:
+            try:
+                segment_prefix = endpoint.split('/')[-1]
+                self.log.debug(
+                    "Failed to upload large object manifest for %s. "
+                    "Removing segment uploads.", segment_prefix)
+                self._delete_autocreated_image_objects(
+                    segment_prefix=segment_prefix)
+            except Exception:
+                self.log.exception(
+                    "Failed to cleanup image objects for %s:",
+                    segment_prefix)
+            raise
 
     def _finish_large_object_slo(self, endpoint, headers, manifest):
         # TODO(mordred) send an etag of the manifest, which is the md5sum
         # of the concatenation of the etags of the results
         headers = headers.copy()
-        return self.put(
-            endpoint,
-            params={'multipart-manifest': 'put'},
-            headers=headers, data=json.dumps(manifest))
+        retries = 3
+        while True:
+            try:
+                return exceptions.raise_from_response(self.put(
+                    endpoint,
+                    params={'multipart-manifest': 'put'},
+                    headers=headers, data=json.dumps(manifest))
+                )
+            except Exception:
+                retries -= 1
+                if retries == 0:
+                    raise
 
     def _finish_large_object_dlo(self, endpoint, headers):
         headers = headers.copy()
         headers['X-Object-Manifest'] = endpoint
-        return self.put(endpoint, headers=headers)
+        retries = 3
+        while True:
+            try:
+                return exceptions.raise_from_response(
+                    self.put(endpoint, headers=headers))
+            except Exception:
+                retries -= 1
+                if retries == 0:
+                    raise
 
     def _upload_object(self, endpoint, filename, headers):
         with open(filename, 'rb') as dt:
-            return proxy._json_response(self.put(
-                endpoint, headers=headers, data=dt))
+            return self.put(
+                endpoint, headers=headers, data=dt)
 
     def _get_file_segments(self, endpoint, filename, file_size, segment_size):
         # Use an ordered dict here so that testing can replicate things
@@ -675,7 +734,9 @@ class Proxy(proxy.Proxy):
                 continue
             name = self._object_name_from_url(result.url)
             for entry in manifest:
-                if entry['path'] == '/{name}'.format(name=name):
+                if entry['path'] == '/{name}'.format(
+                        name=parse.unquote(name)
+                ):
                     entry['etag'] = result.headers['Etag']
 
     def get_info(self):
@@ -689,10 +750,9 @@ class Proxy(proxy.Proxy):
     def set_account_temp_url_key(self, key, secondary=False):
         """Set the temporary URL key for the account.
 
-        :param key:
-          Text of the key to use.
-        :param bool secondary:
-          Whether this should set the secondary key. (defaults to False)
+        :param key: Text of the key to use.
+        :param bool secondary: Whether this should set the secondary key.
+            (defaults to False)
         """
         account = self._get_resource(_account.Account, None)
         account.set_temp_url_key(self, key, secondary)
@@ -700,13 +760,11 @@ class Proxy(proxy.Proxy):
     def set_container_temp_url_key(self, container, key, secondary=False):
         """Set the temporary URL key for a container.
 
-        :param container:
-          The value can be the name of a container or a
-          :class:`~openstack.object_store.v1.container.Container` instance.
-        :param key:
-          Text of the key to use.
-        :param bool secondary:
-          Whether this should set the secondary key. (defaults to False)
+        :param container: The value can be the name of a container or a
+            :class:`~openstack.object_store.v1.container.Container` instance.
+        :param key: Text of the key to use.
+        :param bool secondary: Whether this should set the secondary key.
+            (defaults to False)
         """
         res = self._get_resource(_container.Container, container)
         res.set_temp_url_key(self, key, secondary)
@@ -714,14 +772,12 @@ class Proxy(proxy.Proxy):
     def get_temp_url_key(self, container=None):
         """Get the best temporary url key for a given container.
 
-        Will first try to return Temp-URL-Key-2 then Temp-URL-Key for
-        the container, and if neither exist, will attempt to return
-        Temp-URL-Key-2 then Temp-URL-Key for the account. If neither
-        exist, will return None.
+        Will first try to return Temp-URL-Key-2 then Temp-URL-Key for the
+        container, and if neither exist, will attempt to return Temp-URL-Key-2
+        then Temp-URL-Key for the account. If neither exist, will return None.
 
-        :param container:
-          The value can be the name of a container or a
-          :class:`~openstack.object_store.v1.container.Container` instance.
+        :param container: The value can be the name of a container or a
+            :class:`~openstack.object_store.v1.container.Container` instance.
         """
         temp_url_key = None
         if container:
@@ -753,24 +809,19 @@ class Proxy(proxy.Proxy):
             max_upload_count, timeout, temp_url_key=None):
         """Generate a signature for a FormPost upload.
 
-        :param container:
-          The value can be the name of a container or a
-          :class:`~openstack.object_store.v1.container.Container` instance.
-        :param object_prefix:
-          Prefix to apply to limit all object names created using this
-          signature.
-        :param redirect_url:
-          The URL to redirect the browser to after the uploads have
-          completed.
-        :param max_file_size:
-          The maximum file size per file uploaded.
-        :param max_upload_count:
-          The maximum number of uploaded files allowed.
-        :param timeout:
-          The number of seconds from now to allow the form post to begin.
-        :param temp_url_key:
-          The X-Account-Meta-Temp-URL-Key for the account. Optional, if
-          omitted, the key will be fetched from the container or the account.
+        :param container: The value can be the name of a container or a
+            :class:`~openstack.object_store.v1.container.Container` instance.
+        :param object_prefix: Prefix to apply to limit all object names
+            created using this signature.
+        :param redirect_url: The URL to redirect the browser to after the
+            uploads have completed.
+        :param max_file_size: The maximum file size per file uploaded.
+        :param max_upload_count: The maximum number of uploaded files allowed.
+        :param timeout: The number of seconds from now to allow the form
+            post to begin.
+        :param temp_url_key: The X-Account-Meta-Temp-URL-Key for the account.
+            Optional, if omitted, the key will be fetched from the container
+            or the account.
         """
         max_file_size = int(max_file_size)
         if max_file_size < 1:
@@ -811,9 +862,9 @@ class Proxy(proxy.Proxy):
         :param seconds: time in seconds or ISO 8601 timestamp.
             If absolute is False and this is the string representation of an
             integer, then this specifies the amount of time in seconds for
-            which the temporary URL will be valid.
-            If absolute is True then this specifies an absolute time at which
-            the temporary URL will expire.
+            which the temporary URL will be valid.  If absolute is True then
+            this specifies an absolute time at which the temporary URL will
+            expire.
         :param method: A HTTP method, typically either GET or PUT, to allow
             for this temporary URL.
         :param absolute: if True then the seconds parameter is interpreted as a
@@ -824,9 +875,9 @@ class Proxy(proxy.Proxy):
             instead of a UNIX timestamp will be created.
         :param ip_range: if a valid ip range, restricts the temporary URL to
             the range of ips.
-        :param temp_url_key:
-          The X-Account-Meta-Temp-URL-Key for the account. Optional, if
-          omitted, the key will be fetched from the container or the account.
+        :param temp_url_key: The X-Account-Meta-Temp-URL-Key for the account.
+            Optional, if omitted, the key will be fetched from the container or
+            the account.
         :raises ValueError: if timestamp or path is not in valid format.
         :return: the path portion of a temporary URL
         """
@@ -929,3 +980,34 @@ class Proxy(proxy.Proxy):
             return temp_url.encode('utf-8')
         else:
             return temp_url
+
+    def _delete_autocreated_image_objects(
+        self, container=None, segment_prefix=None
+    ):
+        """Delete all objects autocreated for image uploads.
+
+        This method should generally not be needed, as shade should clean up
+        the objects it uses for object-based image creation. If something goes
+        wrong and it is found that there are leaked objects, this method can be
+        used to delete any objects that shade has created on the user's behalf
+        in service of image uploads.
+
+        :param str container: Name of the container. Defaults to 'images'.
+        :param str segment_prefix: Prefix for the image segment names to
+            delete. If not given, all image upload segments present are
+            deleted.
+        :returns: True if deletion was succesful, else False.
+        """
+        if container is None:
+            container = self._connection._OBJECT_AUTOCREATE_CONTAINER
+        # This method only makes sense on clouds that use tasks
+        if not self._connection.image_api_use_tasks:
+            return False
+
+        deleted = False
+        for obj in self.objects(container, prefix=segment_prefix):
+            meta = self.get_object_metadata(obj).metadata
+            if meta.get(self._connection._OBJECT_AUTOCREATE_KEY) == 'true':
+                self.delete_object(obj, ignore_missing=True)
+                deleted = True
+        return deleted
