@@ -21,12 +21,16 @@ from openstack import resource
 class Object(_base.BaseResource):
     _custom_metadata_prefix = "X-Object-Meta-"
     _system_metadata = {
+        "accept_ranges": "accept-ranges",
         "content_disposition": "content-disposition",
         "content_encoding": "content-encoding",
         "content_type": "content-type",
         "delete_after": "x-delete-after",
         "delete_at": "x-delete-at",
         "is_content_type_detected": "x-detect-content-type",
+        "manifest": "x-object-manifest",
+        # Rax hack - the need CORS as different header
+        "access_control_allow_origin": "access-control-allow-origin"
     }
 
     base_path = "/%(container)s"
@@ -40,7 +44,10 @@ class Object(_base.BaseResource):
     allow_head = True
 
     _query_mapping = resource.QueryParameters(
-        'prefix', 'format'
+        'prefix', 'format',
+        'temp_url_sig', 'temp_url_expires',
+        'filename', 'multipart_manifest', 'symlink',
+        multipart_manifest='multipart-manifest'
     )
 
     # Data to be passed during a POST call to create an object on the server.
@@ -93,6 +100,10 @@ class Object(_base.BaseResource):
     #: signature. For more information about temporary URLs, see
     #: OpenStack Object Storage API v1 Reference.
     expires_at = resource.Header("expires")
+    #: If present, this is a dynamic large object manifest object.
+    #: The value is the container and object name prefix of the segment
+    #: objects in the form container/prefix.
+    manifest = resource.Header("x-object-manifest")
     #: If you include the multipart-manifest=get query parameter and
     #: the object is a large object, the object contents are not
     #: returned. Instead, the manifest is returned in the
@@ -171,11 +182,22 @@ class Object(_base.BaseResource):
     #: Using PUT with X-Copy-From has the same effect as using the
     #: COPY operation to copy an object.
     copy_from = resource.Header("x-copy-from")
+    #: If present, this is a symlink object. The value is the relative path
+    #: of the target object in the format <container>/<object>.
+    symlink_target = resource.Header("x-symlink-target")
+    #: If present, and X-Symlink-Target is present, then this is a
+    #: cross-account symlink to an object in the account specified in the
+    #: value.
+    symlink_target_account = resource.Header("x-symlink-target-account")
+
+    #: CORS for RAX (deviating from standard)
+    access_control_allow_origin = resource.Header(
+        "access-control-allow-origin")
 
     has_body = False
 
     def __init__(self, data=None, **attrs):
-        super(_base.BaseResource, self).__init__(**attrs)
+        super().__init__(**attrs)
         self.data = data
 
     # The Object Store treats the metadata for its resources inconsistently so
@@ -284,13 +306,14 @@ class Object(_base.BaseResource):
             session, error_message=error_message, stream=True)
         return response.iter_content(chunk_size, decode_unicode=False)
 
-    def create(self, session, base_path=None):
+    def create(self, session, base_path=None, **params):
         request = self._prepare_request(base_path=base_path)
 
         response = session.put(
             request.url,
             data=self.data,
-            headers=request.headers)
+            headers=request.headers
+        )
         self._translate_response(response, has_body=False)
         return self
 
@@ -300,7 +323,7 @@ class Object(_base.BaseResource):
 
         request = self._prepare_request()
         session = self._get_session(session)
-        microversion = self._get_microversion_for(session, 'delete')
+        microversion = self._get_microversion(session, action='delete')
 
         if self.is_static_large_object is None:
             # Fetch metadata to determine SLO flag
