@@ -177,12 +177,11 @@ class TestBareMetalNode(base.BaseBaremetalTest):
         node = self.create_node()
         self.assertIsNone(node.power_state)
 
-        self.conn.baremetal.set_node_power_state(node, 'power on')
+        self.conn.baremetal.set_node_power_state(node, 'power on', wait=True)
         node = self.conn.baremetal.get_node(node.id)
-        # Fake nodes react immediately to power requests.
         self.assertEqual('power on', node.power_state)
 
-        self.conn.baremetal.set_node_power_state(node, 'power off')
+        self.conn.baremetal.set_node_power_state(node, 'power off', wait=True)
         node = self.conn.baremetal.get_node(node.id)
         self.assertEqual('power off', node.power_state)
 
