@@ -17,11 +17,11 @@ test_clustering
 Functional tests for `shade` clustering methods.
 """
 
+import time
+
 from testtools import content
 
-from openstack.tests.functional.cloud import base
-
-import time
+from openstack.tests.functional import base
 
 
 def wait_for_status(client, client_args, field, value, check_interval=1,
@@ -105,7 +105,7 @@ def wait_for_delete(client, client_args, check_interval=1, timeout=60):
     return True
 
 
-class TestClustering(base.BaseFunctionalTestCase):
+class TestClustering(base.BaseFunctionalTest):
 
     def setUp(self):
         super(TestClustering, self).setUp()
@@ -115,8 +115,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -145,8 +145,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -189,8 +189,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -232,8 +232,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -318,8 +318,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -392,8 +392,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -474,8 +474,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -567,8 +567,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -656,8 +656,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -713,8 +713,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -775,8 +775,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -863,8 +863,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -914,8 +914,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -1018,8 +1018,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -1056,8 +1056,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -1094,8 +1094,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -1130,8 +1130,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -1297,8 +1297,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
@@ -1356,8 +1356,8 @@ class TestClustering(base.BaseFunctionalTestCase):
         profile_name = "test_profile"
         spec = {
             "properties": {
-                "flavor": "m1.tiny",
-                "image": "cirros-0.3.5-x86_64-disk",
+                "flavor": self.flavor.name,
+                "image": self.image.name,
                 "networks": [
                     {
                         "network": "private"
