@@ -17,8 +17,8 @@ class TestLimits(base.BaseFunctionalTest):
 
     def test_limits(self):
         sot = self.conn.compute.get_limits()
-        self.assertIn('maxTotalInstances', sot.absolute)
-        self.assertIn('maxTotalRAMSize', sot.absolute)
-        self.assertIn('maxTotalKeypairs', sot.absolute)
-        self.assertIn('maxSecurityGroups', sot.absolute)
-        self.assertIn('maxSecurityGroupRules', sot.absolute)
+        self.assertIsNotNone(sot.absolute['instances'])
+        self.assertIsNotNone(sot.absolute['total_ram'])
+        self.assertIsNotNone(sot.absolute['keypairs'])
+        self.assertIsNotNone(sot.absolute['security_groups'])
+        self.assertIsNotNone(sot.absolute['security_group_rules'])
