@@ -23,6 +23,7 @@ from testscenarios import load_tests_apply_scenarios as load_tests  # noqa
 
 from openstack.cloud import exc
 from openstack import exceptions
+from openstack.network.v2 import port as _port
 from openstack.tests import fakes
 from openstack.tests.unit import base
 
@@ -71,13 +72,13 @@ class TestBaremetalNode(base.IronicTestCase):
 
     def test_get_machine_by_mac(self):
         mac_address = '00:01:02:03:04:05'
-        url_address = 'detail?address=%s' % mac_address
         node_uuid = self.fake_baremetal_node['uuid']
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
                      resource='ports',
-                     append=[url_address]),
+                     append=['detail'],
+                     qs_elements=['address=%s' % mac_address]),
                  json={'ports': [{'address': mac_address,
                                   'node_uuid': node_uuid}]}),
             dict(method='GET',
@@ -1656,9 +1657,10 @@ class TestBaremetalNode(base.IronicTestCase):
                 method='GET',
                 uri=self.get_mock_url(
                     service_type='network',
-                    resource='ports.json',
-                    base_url_append='v2.0'),
-                json={'ports': [{'id': vif_id}]}),
+                    resource='ports',
+                    base_url_append='v2.0',
+                    append=[vif_id]),
+                json={'id': vif_id}),
             dict(
                 method='POST',
                 uri=self.get_mock_url(
@@ -1682,9 +1684,10 @@ class TestBaremetalNode(base.IronicTestCase):
                 method='GET',
                 uri=self.get_mock_url(
                     service_type='network',
-                    resource='ports.json',
-                    base_url_append='v2.0'),
-                json={'ports': [{'id': vif_id}]}),
+                    resource='ports',
+                    base_url_append='v2.0',
+                    append=[vif_id]),
+                json={'id': vif_id}),
             dict(
                 method='DELETE',
                 uri=self.get_mock_url(
@@ -1716,14 +1719,17 @@ class TestBaremetalNode(base.IronicTestCase):
                 method='GET',
                 uri=self.get_mock_url(
                     service_type='network',
-                    resource='ports.json',
-                    base_url_append='v2.0'),
-                json={'ports': [fake_port]}),
+                    resource='ports',
+                    base_url_append='v2.0',
+                    append=[vif_id]),
+                json=fake_port),
         ])
         res = self.cloud.list_ports_attached_to_machine(
             self.fake_baremetal_node['uuid'])
         self.assert_calls()
-        self.assertEqual([fake_port], res)
+        self.assertEqual(
+            [_port.Port(**fake_port).to_dict(computed=False)],
+            [i.to_dict(computed=False) for i in res])
 
 
 class TestUpdateMachinePatch(base.IronicTestCase):
