@@ -21,6 +21,7 @@ Tests Floating IP resource methods for Neutron
 
 import copy
 import datetime
+
 import munch
 
 from openstack.cloud import exc
@@ -164,7 +165,7 @@ class TestFloatingIP(base.TestCase):
     def test_list_floating_ips(self):
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/floatingips.json',
+                 uri='https://network.example.com/v2.0/floatingips',
                  json=self.mock_floating_ip_list_rep)])
 
         floating_ips = self.cloud.list_floating_ips()
@@ -179,18 +180,18 @@ class TestFloatingIP(base.TestCase):
 
         self.register_uris([
             dict(method='GET',
-                 uri=('https://network.example.com/v2.0/floatingips.json?'
-                      'Foo=42'),
+                 uri=('https://network.example.com/v2.0/floatingips?'
+                      'description=42'),
                  json={'floatingips': []})])
 
-        self.cloud.list_floating_ips(filters={'Foo': 42})
+        self.cloud.list_floating_ips(filters={'description': 42})
 
         self.assert_calls()
 
     def test_search_floating_ips(self):
         self.register_uris([
             dict(method='GET',
-                 uri=('https://network.example.com/v2.0/floatingips.json'),
+                 uri=('https://network.example.com/v2.0/floatingips'),
                  json=self.mock_floating_ip_list_rep)])
 
         floating_ips = self.cloud.search_floating_ips(
@@ -204,7 +205,7 @@ class TestFloatingIP(base.TestCase):
     def test_get_floating_ip(self):
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/floatingips.json',
+                 uri='https://network.example.com/v2.0/floatingips',
                  json=self.mock_floating_ip_list_rep)])
 
         floating_ip = self.cloud.get_floating_ip(
@@ -226,7 +227,7 @@ class TestFloatingIP(base.TestCase):
     def test_get_floating_ip_not_found(self):
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/floatingips.json',
+                 uri='https://network.example.com/v2.0/floatingips',
                  json=self.mock_floating_ip_list_rep)])
 
         floating_ip = self.cloud.get_floating_ip(id='non-existent')
@@ -260,10 +261,14 @@ class TestFloatingIP(base.TestCase):
     def test_create_floating_ip(self):
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/networks.json',
+                 uri='https://network.example.com/v2.0/networks/my-network',
+                 status_code=404),
+            dict(method='GET',
+                 uri='https://network.example.com/v2.0/networks'
+                     '?name=my-network',
                  json={'networks': [self.mock_get_network_rep]}),
             dict(method='POST',
-                 uri='https://network.example.com/v2.0/floatingips.json',
+                 uri='https://network.example.com/v2.0/floatingips',
                  json=self.mock_floating_ip_new_rep,
                  validate=dict(
                      json={'floatingip': {
@@ -279,10 +284,10 @@ class TestFloatingIP(base.TestCase):
     def test_create_floating_ip_port_bad_response(self):
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/networks.json',
-                 json={'networks': [self.mock_get_network_rep]}),
+                 uri='https://network.example.com/v2.0/networks/my-network',
+                 json=self.mock_get_network_rep),
             dict(method='POST',
-                 uri='https://network.example.com/v2.0/floatingips.json',
+                 uri='https://network.example.com/v2.0/floatingips',
                  json=self.mock_floating_ip_new_rep,
                  validate=dict(
                      json={'floatingip': {
@@ -300,10 +305,14 @@ class TestFloatingIP(base.TestCase):
     def test_create_floating_ip_port(self):
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/networks.json',
+                 uri='https://network.example.com/v2.0/networks/my-network',
+                 status_code=404),
+            dict(method='GET',
+                 uri='https://network.example.com/v2.0/networks'
+                     '?name=my-network',
                  json={'networks': [self.mock_get_network_rep]}),
             dict(method='POST',
-                 uri='https://network.example.com/v2.0/floatingips.json',
+                 uri='https://network.example.com/v2.0/floatingips',
                  json=self.mock_floating_ip_port_rep,
                  validate=dict(
                      json={'floatingip': {
@@ -323,13 +332,13 @@ class TestFloatingIP(base.TestCase):
         """
         Test without specifying a network name.
         """
-        fips_mock_uri = 'https://network.example.com/v2.0/floatingips.json'
+        fips_mock_uri = 'https://network.example.com/v2.0/floatingips'
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/networks.json',
+                 uri='https://network.example.com/v2.0/networks',
                  json={'networks': [self.mock_get_network_rep]}),
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/subnets.json',
+                 uri='https://network.example.com/v2.0/subnets',
                  json={'subnets': []}),
             dict(method='GET', uri=fips_mock_uri, json={'floatingips': []}),
             dict(method='POST', uri=fips_mock_uri,
@@ -348,13 +357,13 @@ class TestFloatingIP(base.TestCase):
         """
         Test with specifying a network name.
         """
-        fips_mock_uri = 'https://network.example.com/v2.0/floatingips.json'
+        fips_mock_uri = 'https://network.example.com/v2.0/floatingips'
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/networks.json',
+                 uri='https://network.example.com/v2.0/networks',
                  json={'networks': [self.mock_get_network_rep]}),
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/subnets.json',
+                 uri='https://network.example.com/v2.0/subnets',
                  json={'subnets': []}),
             dict(method='GET', uri=fips_mock_uri, json={'floatingips': []}),
             dict(method='POST', uri=fips_mock_uri,
@@ -377,10 +386,10 @@ class TestFloatingIP(base.TestCase):
         """
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/networks.json',
+                 uri='https://network.example.com/v2.0/networks',
                  json={'networks': [self.mock_get_network_rep]}),
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/subnets.json',
+                 uri='https://network.example.com/v2.0/subnets',
                  json={'subnets': []})
         ])
 
@@ -395,7 +404,10 @@ class TestFloatingIP(base.TestCase):
         # payloads taken from citycloud
         self.register_uris([
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/networks.json',
+                 uri='https://network.example.com/v2.0/networks/ext-net',
+                 status_code=404),
+            dict(method='GET',
+                 uri='https://network.example.com/v2.0/networks?name=ext-net',
                  json={"networks": [{
                      "status": "ACTIVE",
                      "subnets": [
@@ -416,27 +428,9 @@ class TestFloatingIP(base.TestCase):
                      "shared": False,
                      "id": "0232c17f-2096-49bc-b205-d3dcd9a30ebf",
                      "description": None
-                 }, {
-                     "status": "ACTIVE",
-                     "subnets": ["f0ad1df5-53ee-473f-b86b-3604ea5591e9"],
-                     "availability_zone_hints": [],
-                     "availability_zones": ["nova"],
-                     "name": "private",
-                     "admin_state_up": True,
-                     "tenant_id": "65222a4d09ea4c68934fa1028c77f394",
-                     "created_at": "2016-10-22T13:46:26",
-                     "tags": [],
-                     "updated_at": "2016-10-22T13:46:26",
-                     "ipv6_address_scope": None,
-                     "router:external": False,
-                     "ipv4_address_scope": None,
-                     "shared": False,
-                     "mtu": 1450,
-                     "id": "2c9adcb5-c123-4c5a-a2ba-1ad4c4e1481f",
-                     "description": ""
                  }]}),
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/ports.json'
+                 uri='https://network.example.com/v2.0/ports'
                      '?device_id=f80e3ad0-e13e-41d4-8e9c-be79bccdb8f7',
                  json={"ports": [{
                      "status": "ACTIVE",
@@ -463,7 +457,7 @@ class TestFloatingIP(base.TestCase):
                  }]}),
 
             dict(method='POST',
-                 uri='https://network.example.com/v2.0/floatingips.json',
+                 uri='https://network.example.com/v2.0/floatingips',
                  json={"floatingip": {
                      "router_id": "9de9c787-8f89-4a53-8468-a5533d6d7fd1",
                      "status": "DOWN",
@@ -482,6 +476,7 @@ class TestFloatingIP(base.TestCase):
                      "fixed_ip_address": "10.4.0.16",
                      "port_id": "a767944e-057a-47d1-a669-824a21b8fb7b",
                  }})),
+            self.get_nova_discovery_mock_dict(),
             dict(method='GET',
                  uri='{endpoint}/servers/detail'.format(
                      endpoint=fakes.COMPUTE_ENDPOINT),
@@ -524,7 +519,7 @@ class TestFloatingIP(base.TestCase):
                      "metadata": {}
                  }]}),
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/networks.json',
+                 uri='https://network.example.com/v2.0/networks',
                  json={"networks": [{
                      "status": "ACTIVE",
                      "subnets": [
@@ -565,7 +560,7 @@ class TestFloatingIP(base.TestCase):
                      "description": ""
                  }]}),
             dict(method='GET',
-                 uri='https://network.example.com/v2.0/subnets.json',
+                 uri='https://network.example.com/v2.0/subnets',
                  json={"subnets": [{
                      "description": "",
                      "enable_dhcp": True,
@@ -608,19 +603,19 @@ class TestFloatingIP(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'networks': [self.mock_get_network_rep]}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'subnets.json']),
+                     'network', 'public', append=['v2.0', 'subnets']),
                  json={'subnets': []}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': []}),
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  validate=dict(
                      json={'floatingip': {
                          'floating_network_id': 'my-network-id'}}),
@@ -645,29 +640,29 @@ class TestFloatingIP(base.TestCase):
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(fip_id)]),
+                     append=['v2.0', 'floatingips/{0}'.format(fip_id)]),
                  json={}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': [fake_fip]}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(fip_id)]),
+                     append=['v2.0', 'floatingips/{0}'.format(fip_id)]),
                  json={}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': [fake_fip]}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(fip_id)]),
+                     append=['v2.0', 'floatingips/{0}'.format(fip_id)]),
                  json={}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': []}),
         ])
 
@@ -691,20 +686,20 @@ class TestFloatingIP(base.TestCase):
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(fip_id)]),
+                     append=['v2.0', 'floatingips/{0}'.format(fip_id)]),
                  json={}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': [fake_fip]}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(fip_id)]),
+                     append=['v2.0', 'floatingips/{0}'.format(fip_id)]),
                  json={}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': [down_fip]}),
         ])
 
@@ -723,29 +718,29 @@ class TestFloatingIP(base.TestCase):
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(fip_id)]),
+                     append=['v2.0', 'floatingips/{0}'.format(fip_id)]),
                  json={}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': [fake_fip]}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(fip_id)]),
+                     append=['v2.0', 'floatingips/{0}'.format(fip_id)]),
                  json={}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': [fake_fip]}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(fip_id)]),
+                     append=['v2.0', 'floatingips/{0}'.format(fip_id)]),
                  json={}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': [fake_fip]}),
         ])
         self.assertRaises(
@@ -758,7 +753,7 @@ class TestFloatingIP(base.TestCase):
         self.register_uris([
             dict(method='DELETE',
                  uri=('https://network.example.com/v2.0/floatingips/'
-                      'a-wild-id-appears.json'),
+                      'a-wild-id-appears'),
                  status_code=404)])
 
         ret = self.cloud.delete_floating_ip(
@@ -768,21 +763,23 @@ class TestFloatingIP(base.TestCase):
         self.assert_calls()
 
     def test_attach_ip_to_server(self):
-        fip = self.mock_floating_ip_list_rep['floatingips'][0]
+        fip = self.mock_floating_ip_list_rep['floatingips'][0].copy()
+        fip.update({'status': 'DOWN', 'port_id': None, 'router_id': None})
         device_id = self.fake_server['id']
 
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'ports.json'],
+                     'network', 'public', append=['v2.0', 'ports'],
                      qs_elements=["device_id={0}".format(device_id)]),
                  json={'ports': self.mock_search_ports_rep}),
             dict(method='PUT',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(
+                     append=['v2.0', 'floatingips/{0}'.format(
                          fip['id'])]),
-                 json={'floatingip': fip},
+                 json={'floatingip':
+                       self.mock_floating_ip_list_rep['floatingips'][0]},
                  validate=dict(
                      json={'floatingip': {
                          'port_id': self.mock_search_ports_rep[0]['id'],
@@ -792,57 +789,7 @@ class TestFloatingIP(base.TestCase):
 
         self.cloud._attach_ip_to_server(
             server=self.fake_server,
-            floating_ip=self.floating_ip)
-        self.assert_calls()
-
-    def test_add_ip_refresh_timeout(self):
-        device_id = self.fake_server['id']
-
-        self.register_uris([
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'network', 'public',
-                     append=['v2.0', 'networks.json']),
-                 json={'networks': [self.mock_get_network_rep]}),
-            dict(method='GET',
-                 uri='https://network.example.com/v2.0/subnets.json',
-                 json={'subnets': []}),
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'ports.json'],
-                     qs_elements=["device_id={0}".format(device_id)]),
-                 json={'ports': self.mock_search_ports_rep}),
-            dict(method='POST',
-                 uri='https://network.example.com/v2.0/floatingips.json',
-                 json={'floatingip': self.floating_ip},
-                 validate=dict(
-                     json={'floatingip': {
-                         'floating_network_id': 'my-network-id',
-                         'fixed_ip_address': self.mock_search_ports_rep[0][
-                             'fixed_ips'][0]['ip_address'],
-                         'port_id': self.mock_search_ports_rep[0]['id']}})),
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
-                 json={'floatingips': [self.floating_ip]}),
-            dict(method='DELETE',
-                 uri=self.get_mock_url(
-                     'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(
-                         self.floating_ip['id'])]),
-                 json={}),
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
-                 json={'floatingips': []}),
-        ])
-
-        self.assertRaises(
-            exc.OpenStackCloudTimeout,
-            self.cloud._add_auto_ip,
-            server=self.fake_server,
-            wait=True, timeout=0.01,
-            reuse=False)
+            floating_ip=self.cloud._normalize_floating_ip(fip))
         self.assert_calls()
 
     def test_detach_ip_from_server(self):
@@ -852,12 +799,12 @@ class TestFloatingIP(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': [attached_fip]}),
             dict(method='PUT',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(
+                     append=['v2.0', 'floatingips/{0}'.format(
                          fip['id'])]),
                  json={'floatingip': fip},
                  validate=dict(
@@ -876,33 +823,33 @@ class TestFloatingIP(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'networks': [network]}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'subnets.json']),
+                     'network', 'public', append=['v2.0', 'subnets']),
                  json={'subnets': []}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': [fip]}),
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingip': fip},
                  validate=dict(
                      json={'floatingip': {
                          'floating_network_id': network['id']}})),
             dict(method="GET",
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'ports.json'],
+                     'network', 'public', append=['v2.0', 'ports'],
                      qs_elements=[
                         "device_id={0}".format(self.fake_server['id'])]),
                  json={'ports': self.mock_search_ports_rep}),
             dict(method='PUT',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(
+                     append=['v2.0', 'floatingips/{0}'.format(
                          fip['id'])]),
                  json={'floatingip': fip},
                  validate=dict(
@@ -928,6 +875,14 @@ class TestFloatingIP(base.TestCase):
             "network": "this-is-a-net-or-pool-id",
             "port_id": None,
             "status": "ACTIVE"
+        }, {
+            "id": "this-is-a-second-floating-ip-id",
+            "fixed_ip_address": None,
+            "internal_network": None,
+            "floating_ip_address": "203.0.113.30",
+            "network": "this-is-a-net-or-pool-id",
+            "port_id": None,
+            "status": "ACTIVE"
         }, {
             "id": "this-is-an-attached-floating-ip-id",
             "fixed_ip_address": None,
@@ -941,20 +896,32 @@ class TestFloatingIP(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingips': floating_ips}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'floatingips/{0}.json'.format(
+                     append=['v2.0', 'floatingips/{0}'.format(
                          floating_ips[0]['id'])]),
                  json={}),
+            # First IP has been deleted now, return just the second
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'floatingips']),
+                 json={'floatingips': floating_ips[1:]}),
+            dict(method='DELETE',
+                 uri=self.get_mock_url(
+                     'network', 'public',
+                     append=['v2.0', 'floatingips/{0}'.format(
+                         floating_ips[1]['id'])]),
+                 json={}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
-                 json={'floatingips': [floating_ips[1]]}),
+                     'network', 'public', append=['v2.0', 'floatingips']),
+                 json={'floatingips': [floating_ips[2]]}),
         ])
-        self.cloud.delete_unattached_floating_ips()
+        cleaned_up = self.cloud.delete_unattached_floating_ips()
+        self.assertEqual(cleaned_up, 2)
         self.assert_calls()
 
     def test_create_floating_ip_no_port(self):
@@ -976,20 +943,20 @@ class TestFloatingIP(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'networks': [self.mock_get_network_rep]}),
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'subnets.json']),
+                     'network', 'public', append=['v2.0', 'subnets']),
                  json={'subnets': []}),
             dict(method="GET",
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'ports.json'],
+                     'network', 'public', append=['v2.0', 'ports'],
                      qs_elements=['device_id=some-server']),
                  json={'ports': [server_port]}),
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'floatingips.json']),
+                     'network', 'public', append=['v2.0', 'floatingips']),
                  json={'floatingip': floating_ip})
         ])
 
@@ -998,3 +965,197 @@ class TestFloatingIP(base.TestCase):
             self.cloud._neutron_create_floating_ip,
             server=dict(id='some-server'))
         self.assert_calls()
+
+    def test_find_nat_source_inferred(self):
+        # payloads contrived but based on ones from citycloud
+        self.register_uris([
+            dict(method='GET',
+                 uri='https://network.example.com/v2.0/networks',
+                 json={"networks": [{
+                     "status": "ACTIVE",
+                     "subnets": [
+                         "df3e17fa-a4b2-47ae-9015-bc93eb076ba2",
+                         "6b0c3dc9-b0b8-4d87-976a-7f2ebf13e7ec",
+                         "fc541f48-fc7f-48c0-a063-18de6ee7bdd7"],
+                     "availability_zone_hints": [],
+                     "availability_zones": ["nova"],
+                     "name": "ext-net",
+                     "admin_state_up": True,
+                     "tenant_id": "a564613210ee43708b8a7fc6274ebd63",
+                     "tags": [],
+                     "ipv6_address_scope": "9f03124f-89af-483a-b6fd-10f08079db4d",  # noqa
+                     "mtu": 0,
+                     "is_default": False,
+                     "router:external": True,
+                     "ipv4_address_scope": None,
+                     "shared": False,
+                     "id": "0232c17f-2096-49bc-b205-d3dcd9a30ebf",
+                     "description": None
+                 }, {
+                     "status": "ACTIVE",
+                     "subnets": [
+                         "df3e17fa-a4b2-47ae-9015-bc93eb076ba2",
+                         "6b0c3dc9-b0b8-4d87-976a-7f2ebf13e7ec",
+                         "fc541f48-fc7f-48c0-a063-18de6ee7bdd7"],
+                     "availability_zone_hints": [],
+                     "availability_zones": ["nova"],
+                     "name": "my-network",
+                     "admin_state_up": True,
+                     "tenant_id": "a564613210ee43708b8a7fc6274ebd63",
+                     "tags": [],
+                     "ipv6_address_scope": "9f03124f-89af-483a-b6fd-10f08079db4d",  # noqa
+                     "mtu": 0,
+                     "is_default": False,
+                     "router:external": True,
+                     "ipv4_address_scope": None,
+                     "shared": False,
+                     "id": "0232c17f-2096-49bc-b205-d3dcd9a30ebg",
+                     "description": None
+                 }, {
+                     "status": "ACTIVE",
+                     "subnets": ["f0ad1df5-53ee-473f-b86b-3604ea5591e9"],
+                     "availability_zone_hints": [],
+                     "availability_zones": ["nova"],
+                     "name": "private",
+                     "admin_state_up": True,
+                     "tenant_id": "65222a4d09ea4c68934fa1028c77f394",
+                     "created_at": "2016-10-22T13:46:26",
+                     "tags": [],
+                     "updated_at": "2016-10-22T13:46:26",
+                     "ipv6_address_scope": None,
+                     "router:external": False,
+                     "ipv4_address_scope": None,
+                     "shared": False,
+                     "mtu": 1450,
+                     "id": "2c9adcb5-c123-4c5a-a2ba-1ad4c4e1481f",
+                     "description": ""
+                 }]}),
+            dict(method='GET',
+                 uri='https://network.example.com/v2.0/subnets',
+                 json={"subnets": [{
+                     "description": "",
+                     "enable_dhcp": True,
+                     "network_id": "2c9adcb5-c123-4c5a-a2ba-1ad4c4e1481f",
+                     "tenant_id": "65222a4d09ea4c68934fa1028c77f394",
+                     "created_at": "2016-10-22T13:46:26",
+                     "dns_nameservers": [
+                         "89.36.90.101",
+                         "89.36.90.102"],
+                     "updated_at": "2016-10-22T13:46:26",
+                     "gateway_ip": "10.4.0.1",
+                     "ipv6_ra_mode": None,
+                     "allocation_pools": [{
+                         "start": "10.4.0.2",
+                         "end": "10.4.0.200"}],
+                     "host_routes": [],
+                     "ip_version": 4,
+                     "ipv6_address_mode": None,
+                     "cidr": "10.4.0.0/24",
+                     "id": "f0ad1df5-53ee-473f-b86b-3604ea5591e9",
+                     "subnetpool_id": None,
+                     "name": "private-subnet-ipv4",
+                 }]})
+        ])
+
+        self.assertEqual(
+            'ext-net', self.cloud.get_nat_source()['name'])
+
+        self.assert_calls()
+
+    def test_find_nat_source_config(self):
+        self.cloud._nat_source = 'my-network'
+
+        # payloads contrived but based on ones from citycloud
+        self.register_uris([
+            dict(method='GET',
+                 uri='https://network.example.com/v2.0/networks',
+                 json={"networks": [{
+                     "status": "ACTIVE",
+                     "subnets": [
+                         "df3e17fa-a4b2-47ae-9015-bc93eb076ba2",
+                         "6b0c3dc9-b0b8-4d87-976a-7f2ebf13e7ec",
+                         "fc541f48-fc7f-48c0-a063-18de6ee7bdd7"],
+                     "availability_zone_hints": [],
+                     "availability_zones": ["nova"],
+                     "name": "ext-net",
+                     "admin_state_up": True,
+                     "tenant_id": "a564613210ee43708b8a7fc6274ebd63",
+                     "tags": [],
+                     "ipv6_address_scope": "9f03124f-89af-483a-b6fd-10f08079db4d",  # noqa
+                     "mtu": 0,
+                     "is_default": False,
+                     "router:external": True,
+                     "ipv4_address_scope": None,
+                     "shared": False,
+                     "id": "0232c17f-2096-49bc-b205-d3dcd9a30ebf",
+                     "description": None
+                 }, {
+                     "status": "ACTIVE",
+                     "subnets": [
+                         "df3e17fa-a4b2-47ae-9015-bc93eb076ba2",
+                         "6b0c3dc9-b0b8-4d87-976a-7f2ebf13e7ec",
+                         "fc541f48-fc7f-48c0-a063-18de6ee7bdd7"],
+                     "availability_zone_hints": [],
+                     "availability_zones": ["nova"],
+                     "name": "my-network",
+                     "admin_state_up": True,
+                     "tenant_id": "a564613210ee43708b8a7fc6274ebd63",
+                     "tags": [],
+                     "ipv6_address_scope": "9f03124f-89af-483a-b6fd-10f08079db4d",  # noqa
+                     "mtu": 0,
+                     "is_default": False,
+                     "router:external": True,
+                     "ipv4_address_scope": None,
+                     "shared": False,
+                     "id": "0232c17f-2096-49bc-b205-d3dcd9a30ebg",
+                     "description": None
+                 }, {
+                     "status": "ACTIVE",
+                     "subnets": ["f0ad1df5-53ee-473f-b86b-3604ea5591e9"],
+                     "availability_zone_hints": [],
+                     "availability_zones": ["nova"],
+                     "name": "private",
+                     "admin_state_up": True,
+                     "tenant_id": "65222a4d09ea4c68934fa1028c77f394",
+                     "created_at": "2016-10-22T13:46:26",
+                     "tags": [],
+                     "updated_at": "2016-10-22T13:46:26",
+                     "ipv6_address_scope": None,
+                     "router:external": False,
+                     "ipv4_address_scope": None,
+                     "shared": False,
+                     "mtu": 1450,
+                     "id": "2c9adcb5-c123-4c5a-a2ba-1ad4c4e1481f",
+                     "description": ""
+                 }]}),
+            dict(method='GET',
+                 uri='https://network.example.com/v2.0/subnets',
+                 json={"subnets": [{
+                     "description": "",
+                     "enable_dhcp": True,
+                     "network_id": "2c9adcb5-c123-4c5a-a2ba-1ad4c4e1481f",
+                     "tenant_id": "65222a4d09ea4c68934fa1028c77f394",
+                     "created_at": "2016-10-22T13:46:26",
+                     "dns_nameservers": [
+                         "89.36.90.101",
+                         "89.36.90.102"],
+                     "updated_at": "2016-10-22T13:46:26",
+                     "gateway_ip": "10.4.0.1",
+                     "ipv6_ra_mode": None,
+                     "allocation_pools": [{
+                         "start": "10.4.0.2",
+                         "end": "10.4.0.200"}],
+                     "host_routes": [],
+                     "ip_version": 4,
+                     "ipv6_address_mode": None,
+                     "cidr": "10.4.0.0/24",
+                     "id": "f0ad1df5-53ee-473f-b86b-3604ea5591e9",
+                     "subnetpool_id": None,
+                     "name": "private-subnet-ipv4",
+                 }]})
+        ])
+
+        self.assertEqual(
+            'my-network', self.cloud.get_nat_source()['name'])
+
+        self.assert_calls()
