@@ -11,10 +11,12 @@
 # limitations under the License.
 
 import copy
+
 import testtools
 
 import openstack
 import openstack.cloud
+from openstack.network.v2 import network as _network
 from openstack.tests.unit import base
 
 
@@ -43,10 +45,11 @@ class TestNetwork(base.TestCase):
         'qos_policy_id': None,
         'name': 'netname',
         'admin_state_up': True,
-        'tenant_id': '861808a93da0484ea1767967c4df8a23',
         'created_at': '2017-04-22T19:22:53Z',
         'mtu': 0,
-        'dns_domain': 'sample.openstack.org.'
+        'dns_domain': 'sample.openstack.org.',
+        'vlan_transparent': None,
+        'segments': None,
     }
 
     network_availability_zone_extension = {
@@ -59,24 +62,32 @@ class TestNetwork(base.TestCase):
 
     enabled_neutron_extensions = [network_availability_zone_extension]
 
+    def _compare_networks(self, exp, real):
+        self.assertDictEqual(
+            _network.Network(**exp).to_dict(computed=False),
+            real.to_dict(computed=False))
+
     def test_list_networks(self):
         net1 = {'id': '1', 'name': 'net1'}
         net2 = {'id': '2', 'name': 'net2'}
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'networks': [net1, net2]})
         ])
         nets = self.cloud.list_networks()
-        self.assertEqual([net1, net2], nets)
+        self.assertEqual(
+            [_network.Network(**i).to_dict(computed=False) for i in [
+                net1, net2]],
+            [i.to_dict(computed=False) for i in nets])
         self.assert_calls()
 
     def test_list_networks_filtered(self):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json'],
+                     'network', 'public', append=['v2.0', 'networks'],
                      qs_elements=["name=test"]),
                  json={'networks': []})
         ])
@@ -87,7 +98,7 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'network': self.mock_new_network_rep},
                  validate=dict(
                      json={'network': {
@@ -95,7 +106,8 @@ class TestNetwork(base.TestCase):
                          'name': 'netname'}}))
         ])
         network = self.cloud.create_network("netname")
-        self.assertEqual(self.mock_new_network_rep, network)
+        self._compare_networks(
+            self.mock_new_network_rep, network)
         self.assert_calls()
 
     def test_create_network_specific_tenant(self):
@@ -105,16 +117,16 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'network': mock_new_network_rep},
                  validate=dict(
                      json={'network': {
                          'admin_state_up': True,
                          'name': 'netname',
-                         'tenant_id': project_id}}))
+                         'project_id': project_id}}))
         ])
         network = self.cloud.create_network("netname", project_id=project_id)
-        self.assertEqual(mock_new_network_rep, network)
+        self._compare_networks(mock_new_network_rep, network)
         self.assert_calls()
 
     def test_create_network_external(self):
@@ -123,7 +135,7 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'network': mock_new_network_rep},
                  validate=dict(
                      json={'network': {
@@ -132,7 +144,7 @@ class TestNetwork(base.TestCase):
                          'router:external': True}}))
         ])
         network = self.cloud.create_network("netname", external=True)
-        self.assertEqual(mock_new_network_rep, network)
+        self._compare_networks(mock_new_network_rep, network)
         self.assert_calls()
 
     def test_create_network_provider(self):
@@ -154,24 +166,65 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'network': mock_new_network_rep},
                  validate=dict(
                      json={'network': expected_send_params}))
         ])
         network = self.cloud.create_network("netname", provider=provider_opts)
-        self.assertEqual(mock_new_network_rep, network)
+        self._compare_networks(mock_new_network_rep, network)
+        self.assert_calls()
+
+    def test_update_network_provider(self):
+        network_id = "test-net-id"
+        network_name = "network"
+        network = {'id': network_id, 'name': network_name}
+        provider_opts = {'physical_network': 'mynet',
+                         'network_type': 'vlan',
+                         'segmentation_id': 'vlan1',
+                         'should_not_be_passed': 1}
+        update_network_provider_opts = {
+            'provider:physical_network': 'mynet',
+            'provider:network_type': 'vlan',
+            'provider:segmentation_id': 'vlan1'
+        }
+        mock_update_rep = copy.copy(self.mock_new_network_rep)
+        mock_update_rep.update(update_network_provider_opts)
+        self.register_uris([
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public',
+                     append=['v2.0', 'networks', network_name]),
+                 status_code=404),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'networks'],
+                     qs_elements=['name=%s' % network_name]),
+                 json={'networks': [network]}),
+            dict(method='PUT',
+                 uri=self.get_mock_url(
+                     'network', 'public',
+                     append=['v2.0', 'networks', network_id]),
+                 json={'network': mock_update_rep},
+                 validate=dict(
+                     json={'network': update_network_provider_opts}))
+        ])
+        network = self.cloud.update_network(
+            network_name,
+            provider=provider_opts
+        )
+        self._compare_networks(mock_update_rep, network)
         self.assert_calls()
 
     def test_create_network_with_availability_zone_hints(self):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'extensions.json']),
+                     'network', 'public', append=['v2.0', 'extensions']),
                  json={'extensions': self.enabled_neutron_extensions}),
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'network': self.mock_new_network_rep},
                  validate=dict(
                      json={'network': {
@@ -181,7 +234,7 @@ class TestNetwork(base.TestCase):
         ])
         network = self.cloud.create_network("netname",
                                             availability_zone_hints=['nova'])
-        self.assertEqual(self.mock_new_network_rep, network)
+        self._compare_networks(self.mock_new_network_rep, network)
         self.assert_calls()
 
     def test_create_network_provider_ignored_value(self):
@@ -204,13 +257,13 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'network': mock_new_network_rep},
                  validate=dict(
                      json={'network': expected_send_params}))
         ])
         network = self.cloud.create_network("netname", provider=provider_opts)
-        self.assertEqual(mock_new_network_rep, network)
+        self._compare_networks(mock_new_network_rep, network)
         self.assert_calls()
 
     def test_create_network_wrong_availability_zone_hints_type(self):
@@ -237,7 +290,7 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'network': mock_new_network_rep},
                  validate=dict(
                      json={'network': {
@@ -249,7 +302,7 @@ class TestNetwork(base.TestCase):
             "netname",
             port_security_enabled=port_security_state
         )
-        self.assertEqual(mock_new_network_rep, network)
+        self._compare_networks(mock_new_network_rep, network)
         self.assert_calls()
 
     def test_create_network_with_mtu(self):
@@ -259,7 +312,7 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public', append=['v2.0', 'networks']),
                  json={'network': mock_new_network_rep},
                  validate=dict(
                      json={'network': {
@@ -270,7 +323,7 @@ class TestNetwork(base.TestCase):
         network = self.cloud.create_network("netname",
                                             mtu_size=mtu_size
                                             )
-        self.assertEqual(mock_new_network_rep, network)
+        self._compare_networks(mock_new_network_rep, network)
         self.assert_calls()
 
     def test_create_network_with_wrong_mtu_size(self):
@@ -294,12 +347,18 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public',
+                     append=['v2.0', 'networks', network_name]),
+                 status_code=404),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'networks'],
+                     qs_elements=['name=%s' % network_name]),
                  json={'networks': [network]}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'networks', "%s.json" % network_id]),
+                     append=['v2.0', 'networks', network_id]),
                  json={})
         ])
         self.assertTrue(self.cloud.delete_network(network_name))
@@ -309,7 +368,13 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public',
+                     append=['v2.0', 'networks', 'test-net']),
+                 status_code=404),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'networks'],
+                     qs_elements=['name=test-net']),
                  json={'networks': []}),
         ])
         self.assertFalse(self.cloud.delete_network('test-net'))
@@ -322,12 +387,18 @@ class TestNetwork(base.TestCase):
         self.register_uris([
             dict(method='GET',
                  uri=self.get_mock_url(
-                     'network', 'public', append=['v2.0', 'networks.json']),
+                     'network', 'public',
+                     append=['v2.0', 'networks', network_name]),
+                 status_code=404),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'networks'],
+                     qs_elements=['name=%s' % network_name]),
                  json={'networks': [network]}),
             dict(method='DELETE',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'networks', "%s.json" % network_id]),
+                     append=['v2.0', 'networks', network_id]),
                  status_code=503)
         ])
         self.assertRaises(openstack.cloud.OpenStackCloudException,
@@ -342,7 +413,7 @@ class TestNetwork(base.TestCase):
             dict(method='GET',
                  uri=self.get_mock_url(
                      'network', 'public',
-                     append=['v2.0', 'networks', "%s" % network_id]),
+                     append=['v2.0', 'networks', network_id]),
                  json={'network': network})
         ])
         self.assertTrue(self.cloud.get_network_by_id(network_id))
