@@ -10,9 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.tests.unit import base
-
 from openstack.clustering.v1 import build_info
+from openstack.tests.unit import base
 
 
 FAKE = {
@@ -34,8 +33,7 @@ class TestBuildInfo(base.TestCase):
         sot = build_info.BuildInfo()
         self.assertEqual('/build-info', sot.base_path)
         self.assertEqual('build_info', sot.resource_key)
-        self.assertEqual('clustering', sot.service.service_type)
-        self.assertTrue(sot.allow_get)
+        self.assertTrue(sot.allow_fetch)
 
     def test_instantiate(self):
         sot = build_info.BuildInfo(**FAKE)
