@@ -12,6 +12,7 @@
 
 from unittest import mock
 
+from openstack.compute.v2 import flavor
 from openstack.compute.v2 import server
 from openstack.image.v2 import image
 from openstack.tests.unit import base
@@ -64,7 +65,6 @@ EXAMPLE = {
         'original_name': 'm1.tiny.specs',
         'ram': 512,
         'swap': 0,
-        'vcpus': 1
     },
     'hostId': '2091634baaccdc4c5a1d57069c833e402921df696b7f970791b12ec6',
     'host_status': 'UP',
@@ -97,13 +97,13 @@ EXAMPLE = {
     'name': 'new-server-test',
     'networks': 'auto',
     'os-extended-volumes:volumes_attached': [],
-    'personality': '28',
     'progress': 0,
     'security_groups': [
         {
             'name': 'default'
         }
     ],
+    'server_groups': ['3caf4187-8010-491f-b6f5-a4a68a40371e'],
     'status': 'ACTIVE',
     'tags': [],
     'tenant_id': '6f70656e737461636b20342065766572',
@@ -194,7 +194,7 @@ class TestServer(base.TestCase):
         self.assertEqual(EXAMPLE['created'], sot.created_at)
         self.assertEqual(EXAMPLE['config_drive'], sot.has_config_drive)
         self.assertEqual(EXAMPLE['flavorRef'], sot.flavor_id)
-        self.assertEqual(EXAMPLE['flavor'], sot.flavor)
+        self.assertEqual(flavor.Flavor(**EXAMPLE['flavor']), sot.flavor)
         self.assertEqual(EXAMPLE['hostId'], sot.host_id)
         self.assertEqual(EXAMPLE['host_status'], sot.host_status)
         self.assertEqual(EXAMPLE['id'], sot.id)
@@ -206,6 +206,7 @@ class TestServer(base.TestCase):
         self.assertEqual(EXAMPLE['name'], sot.name)
         self.assertEqual(EXAMPLE['progress'], sot.progress)
         self.assertEqual(EXAMPLE['tenant_id'], sot.project_id)
+        self.assertEqual(EXAMPLE['server_groups'], sot.server_groups)
         self.assertEqual(EXAMPLE['status'], sot.status)
         self.assertEqual(EXAMPLE['updated'], sot.updated_at)
         self.assertEqual(EXAMPLE['user_id'], sot.user_id)
@@ -223,7 +224,6 @@ class TestServer(base.TestCase):
                          sot.terminated_at)
         self.assertEqual(EXAMPLE['security_groups'], sot.security_groups)
         self.assertEqual(EXAMPLE['adminPass'], sot.admin_password)
-        self.assertEqual(EXAMPLE['personality'], sot.personality)
         self.assertEqual(EXAMPLE['block_device_mapping_v2'],
                          sot.block_device_mapping)
         self.assertEqual(EXAMPLE['OS-EXT-SRV-ATTR:host'],
@@ -251,13 +251,20 @@ class TestServer(base.TestCase):
         self.assertEqual(EXAMPLE['trusted_image_certificates'],
                          sot.trusted_image_certificates)
 
+    def test_to_dict_flavor(self):
+        # Ensure to_dict properly resolves flavor and uses defaults for not
+        # specified flavor proerties.
+        sot = server.Server(**EXAMPLE)
+        dct = sot.to_dict()
+        self.assertEqual(0, dct['flavor']['vcpus'])
+
     def test__prepare_server(self):
         zone = 1
         data = 2
         hints = {"hint": 3}
 
         sot = server.Server(id=1, availability_zone=zone, user_data=data,
-                            scheduler_hints=hints)
+                            scheduler_hints=hints, min_count=2, max_count=3)
         request = sot._prepare_request()
 
         self.assertNotIn("OS-EXT-AZ:availability_zone",
@@ -274,6 +281,9 @@ class TestServer(base.TestCase):
                          request.body[sot.resource_key])
         self.assertEqual(request.body["OS-SCH-HNT:scheduler_hints"], hints)
 
+        self.assertEqual(2, request.body[sot.resource_key]['min_count'])
+        self.assertEqual(3, request.body[sot.resource_key]['max_count'])
+
     def test_change_password(self):
         sot = server.Server(**EXAMPLE)
 
@@ -312,12 +322,14 @@ class TestServer(base.TestCase):
         # Let the translate pass through, that portion is tested elsewhere
         sot._translate_response = lambda arg: arg
 
-        result = sot.rebuild(self.sess, name='noo', admin_password='seekr3t',
-                             image='http://image/1', access_ipv4="12.34.56.78",
-                             access_ipv6="fe80::100",
-                             metadata={"meta var": "meta val"},
-                             personality=[{"path": "/etc/motd",
-                                           "contents": "foo"}])
+        result = sot.rebuild(
+            self.sess, name='noo', admin_password='seekr3t',
+            image='http://image/1', access_ipv4="12.34.56.78",
+            access_ipv6="fe80::100",
+            metadata={"meta var": "meta val"},
+            user_data="ZWNobyAiaGVsbG8gd29ybGQi",
+            preserve_ephemeral=False
+        )
 
         self.assertIsInstance(result, server.Server)
 
@@ -330,7 +342,7 @@ class TestServer(base.TestCase):
                 "accessIPv4": "12.34.56.78",
                 "accessIPv6": "fe80::100",
                 "metadata": {"meta var": "meta val"},
-                "personality": [{"path": "/etc/motd", "contents": "foo"}],
+                "user_data": "ZWNobyAiaGVsbG8gd29ybGQi",
                 "preserve_ephemeral": False
             }
         }
@@ -355,7 +367,6 @@ class TestServer(base.TestCase):
                 "name": "nootoo",
                 "imageRef": "http://image/2",
                 "adminPass": "seekr3two",
-                "preserve_ephemeral": False
             }
         }
         headers = {'Accept': ''}
@@ -445,6 +456,7 @@ class TestServer(base.TestCase):
                                        min_microversion='2.1',
                                        max_microversion='2.56')
         self.sess.get_endpoint_data.return_value = self.endpoint_data
+        self.sess.default_microversion = None
 
         image_id = sot.create_image(self.sess, name, metadata)
 
@@ -472,6 +484,7 @@ class TestServer(base.TestCase):
                                        min_microversion='2.1',
                                        max_microversion='2.56')
         self.sess.get_endpoint_data.return_value = self.endpoint_data
+        self.sess.default_microversion = None
 
         self.assertIsNone(self.resp.body, sot.create_image(self.sess, name))
 
@@ -645,6 +658,18 @@ class TestServer(base.TestCase):
         self.sess.post.assert_called_with(
             url, json=body, headers=headers, microversion=None)
 
+    def test_lock_with_options(self):
+        sot = server.Server(**EXAMPLE)
+
+        res = sot.lock(self.sess, locked_reason='Because why not')
+
+        self.assertIsNone(res)
+        url = 'servers/IDENTIFIER/action'
+        body = {'lock': {'locked_reason': 'Because why not'}}
+        headers = {'Accept': ''}
+        self.sess.post.assert_called_with(
+            url, json=body, headers=headers, microversion=None)
+
     def test_unlock(self):
         sot = server.Server(**EXAMPLE)
 
@@ -768,6 +793,20 @@ class TestServer(base.TestCase):
         self.sess.post.assert_called_with(
             url, json=body, headers=headers, microversion=None)
 
+    def test_unshelve_availability_zone(self):
+        sot = server.Server(**EXAMPLE)
+
+        res = sot.unshelve(self.sess, sot.availability_zone)
+
+        self.assertIsNone(res)
+        url = 'servers/IDENTIFIER/action'
+        body = {"unshelve": {
+            "availability_zone": sot.availability_zone
+        }}
+        headers = {'Accept': ''}
+        self.sess.post.assert_called_with(
+            url, json=body, headers=headers, microversion=None)
+
     def test_migrate(self):
         sot = server.Server(**EXAMPLE)
 
@@ -803,6 +842,52 @@ class TestServer(base.TestCase):
         self.sess.post.assert_called_with(
             url, json=body, headers=headers, microversion=None)
 
+    def test_get_console_url(self):
+        sot = server.Server(**EXAMPLE)
+
+        resp = mock.Mock()
+        resp.body = {'console': {'a': 'b'}}
+        resp.json = mock.Mock(return_value=resp.body)
+        resp.status_code = 200
+        self.sess.post.return_value = resp
+
+        res = sot.get_console_url(self.sess, 'novnc')
+        self.sess.post.assert_called_with(
+            'servers/IDENTIFIER/action',
+            json={'os-getVNCConsole': {'type': 'novnc'}},
+            headers={'Accept': ''}, microversion=None)
+        self.assertDictEqual(resp.body['console'], res)
+
+        sot.get_console_url(self.sess, 'xvpvnc')
+        self.sess.post.assert_called_with(
+            'servers/IDENTIFIER/action',
+            json={'os-getVNCConsole': {'type': 'xvpvnc'}},
+            headers={'Accept': ''}, microversion=None)
+
+        sot.get_console_url(self.sess, 'spice-html5')
+        self.sess.post.assert_called_with(
+            'servers/IDENTIFIER/action',
+            json={'os-getSPICEConsole': {'type': 'spice-html5'}},
+            headers={'Accept': ''}, microversion=None)
+
+        sot.get_console_url(self.sess, 'rdp-html5')
+        self.sess.post.assert_called_with(
+            'servers/IDENTIFIER/action',
+            json={'os-getRDPConsole': {'type': 'rdp-html5'}},
+            headers={'Accept': ''}, microversion=None)
+
+        sot.get_console_url(self.sess, 'serial')
+        self.sess.post.assert_called_with(
+            'servers/IDENTIFIER/action',
+            json={'os-getSerialConsole': {'type': 'serial'}},
+            headers={'Accept': ''}, microversion=None)
+
+        self.assertRaises(ValueError,
+                          sot.get_console_url,
+                          self.sess,
+                          'fake_type'
+                          )
+
     def test_live_migrate_no_force(self):
         sot = server.Server(**EXAMPLE)
 
@@ -852,6 +937,7 @@ class TestServer(base.TestCase):
             min_microversion = '2.1'
             max_microversion = '2.25'
         self.sess.get_endpoint_data.return_value = FakeEndpointData()
+        self.sess.default_microversion = None
 
         res = sot.live_migrate(
             self.sess, host='HOST2', force=True, block_migration=False)
@@ -876,6 +962,7 @@ class TestServer(base.TestCase):
             min_microversion = '2.1'
             max_microversion = '2.25'
         self.sess.get_endpoint_data.return_value = FakeEndpointData()
+        self.sess.default_microversion = None
 
         res = sot.live_migrate(
             self.sess, host='HOST2', force=True, block_migration=None)
@@ -900,6 +987,7 @@ class TestServer(base.TestCase):
             min_microversion = '2.1'
             max_microversion = '2.30'
         self.sess.get_endpoint_data.return_value = FakeEndpointData()
+        self.sess.default_microversion = None
 
         res = sot.live_migrate(
             self.sess, host='HOST2', force=False, block_migration=False)
@@ -924,6 +1012,7 @@ class TestServer(base.TestCase):
             min_microversion = '2.1'
             max_microversion = '2.30'
         self.sess.get_endpoint_data.return_value = FakeEndpointData()
+        self.sess.default_microversion = None
 
         res = sot.live_migrate(
             self.sess, host='HOST2', force=True, block_migration=None)
@@ -942,6 +1031,73 @@ class TestServer(base.TestCase):
         self.sess.post.assert_called_with(
             url, json=body, headers=headers, microversion='2.30')
 
+    def test_get_topology(self):
+        sot = server.Server(**EXAMPLE)
+
+        class FakeEndpointData:
+            min_microversion = '2.1'
+            max_microversion = '2.78'
+        self.sess.get_endpoint_data.return_value = FakeEndpointData()
+        self.sess.default_microversion = None
+
+        response = mock.Mock()
+
+        topology = {
+            "nodes": [
+                {
+                    "cpu_pinning": {
+                        "0": 0,
+                        "1": 5
+                    },
+                    "host_node": 0,
+                    "memory_mb": 1024,
+                    "siblings": [
+                        [
+                            0,
+                            1
+                        ]
+                    ],
+                    "vcpu_set": [
+                        0,
+                        1
+                    ]
+                },
+                {
+                    "cpu_pinning": {
+                        "2": 1,
+                        "3": 8
+                    },
+                    "host_node": 1,
+                    "memory_mb": 2048,
+                    "siblings": [
+                        [
+                            2,
+                            3
+                        ]
+                    ],
+                    "vcpu_set": [
+                        2,
+                        3
+                    ]
+                }
+            ],
+            "pagesize_kb": 4
+        }
+
+        response.status_code = 200
+        response.json.return_value = {
+            'topology': topology
+        }
+
+        self.sess.get.return_value = response
+
+        fetched_topology = sot.fetch_topology(self.sess)
+
+        url = 'servers/IDENTIFIER/topology'
+        self.sess.get.assert_called_with(url)
+
+        self.assertEqual(fetched_topology, topology)
+
     def test_get_security_groups(self):
         sot = server.Server(**EXAMPLE)
 
