@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from openstack.identity.v2 import user
 from openstack.tests.unit import base
 
-from openstack.identity.v2 import user
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -30,10 +30,9 @@ class TestUser(base.TestCase):
         self.assertEqual('user', sot.resource_key)
         self.assertEqual('users', sot.resources_key)
         self.assertEqual('/users', sot.base_path)
-        self.assertEqual('identity', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
