@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from openstack.identity.v3 import endpoint
 from openstack.tests.unit import base
 
-from openstack.identity.v3 import endpoint
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -33,17 +33,17 @@ class TestEndpoint(base.TestCase):
         self.assertEqual('endpoint', sot.resource_key)
         self.assertEqual('endpoints', sot.resources_key)
         self.assertEqual('/endpoints', sot.base_path)
-        self.assertEqual('identity', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
-        self.assertEqual('PATCH', sot.update_method)
+        self.assertEqual('PATCH', sot.commit_method)
         self.assertDictEqual(
             {
                 'interface': 'interface',
                 'service_id': 'service_id',
+                'region_id': 'region_id',
                 'limit': 'limit',
                 'marker': 'marker',
             },
