@@ -9,7 +9,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import hashlib
+
 import io
 import operator
 import tempfile
@@ -22,6 +22,7 @@ from openstack import _log
 from openstack import exceptions
 from openstack.image.v2 import image
 from openstack.tests.unit import base
+from openstack import utils
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -83,13 +84,13 @@ EXAMPLE = {
     'auto_disk_config': True,
     'os_type': '49',
     'os_admin_user': 'ubuntu',
-    'hw_qemu_guest_agent': True,
+    'hw_qemu_guest_agent': 'yes',
     'os_require_quiesce': True,
 }
 
 
 def calculate_md5_checksum(data):
-    checksum = hashlib.md5()
+    checksum = utils.md5(usedforsecurity=False)
     for chunk in data:
         checksum.update(chunk)
     return checksum.hexdigest()
@@ -139,25 +140,29 @@ class TestImage(base.TestCase):
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
-        self.assertDictEqual({'created_at': 'created_at',
-                              'is_hidden': 'os_hidden',
-                              'limit': 'limit',
-                              'marker': 'marker',
-                              'member_status': 'member_status',
-                              'name': 'name',
-                              'owner': 'owner',
-                              'protected': 'protected',
-                              'size_max': 'size_max',
-                              'size_min': 'size_min',
-                              'sort': 'sort',
-                              'sort_dir': 'sort_dir',
-                              'sort_key': 'sort_key',
-                              'status': 'status',
-                              'tag': 'tag',
-                              'updated_at': 'updated_at',
-                              'visibility': 'visibility'
-                              },
-                             sot._query_mapping._mapping)
+        self.assertDictEqual(
+            {
+                'created_at': 'created_at',
+                'id': 'id',
+                'is_hidden': 'os_hidden',
+                'limit': 'limit',
+                'marker': 'marker',
+                'member_status': 'member_status',
+                'name': 'name',
+                'owner': 'owner',
+                'protected': 'protected',
+                'size_max': 'size_max',
+                'size_min': 'size_min',
+                'sort': 'sort',
+                'sort_dir': 'sort_dir',
+                'sort_key': 'sort_key',
+                'status': 'status',
+                'tag': 'tag',
+                'updated_at': 'updated_at',
+                'visibility': 'visibility'
+            },
+            sot._query_mapping._mapping,
+        )
 
     def test_make_it(self):
         sot = image.Image(**EXAMPLE)
@@ -406,7 +411,8 @@ class TestImage(base.TestCase):
         self.sess.get.assert_has_calls(
             [mock.call('images/IDENTIFIER/file',
                        stream=False),
-             mock.call('images/IDENTIFIER', microversion=None, params={})])
+             mock.call('images/IDENTIFIER', microversion=None, params={},
+                       skip_cache=False)])
 
         self.assertEqual(rv, resp1)
 
@@ -435,7 +441,8 @@ class TestImage(base.TestCase):
         self.sess.get.assert_has_calls(
             [mock.call('images/IDENTIFIER/file',
                        stream=False),
-             mock.call('images/IDENTIFIER', microversion=None, params={})])
+             mock.call('images/IDENTIFIER', microversion=None, params={},
+                       skip_cache=False)])
 
         self.assertEqual(rv, resp1)
 
@@ -535,7 +542,7 @@ class TestImage(base.TestCase):
 
         self.sess.get.assert_has_calls([
             mock.call('images/' + EXAMPLE['name'], microversion=None,
-                      params={}),
+                      params={}, skip_cache=False),
             mock.call('/images', headers={'Accept': 'application/json'},
                       microversion=None, params={'name': EXAMPLE['name']}),
             mock.call('/images', headers={'Accept': 'application/json'},
