@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from openstack.network.v2 import listener
 from openstack.tests.unit import base
 
-from openstack.network.v2 import listener
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -39,10 +39,9 @@ class TestListener(base.TestCase):
         self.assertEqual('listener', sot.resource_key)
         self.assertEqual('listeners', sot.resources_key)
         self.assertEqual('/lbaas/listeners', sot.base_path)
-        self.assertEqual('network', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
