@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from openstack.network.v2 import network
 from openstack.tests.unit import base
 
-from openstack.network.v2 import network
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -52,10 +52,9 @@ class TestNetwork(base.TestCase):
         self.assertEqual('network', sot.resource_key)
         self.assertEqual('networks', sot.resources_key)
         self.assertEqual('/networks', sot.base_path)
-        self.assertEqual('network', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
@@ -100,7 +99,7 @@ class TestNetwork(base.TestCase):
              'marker': 'marker',
              'description': 'description',
              'name': 'name',
-             'project_id': 'tenant_id',
+             'project_id': 'project_id',
              'status': 'status',
              'ipv4_address_scope_id': 'ipv4_address_scope',
              'ipv6_address_scope_id': 'ipv6_address_scope',
@@ -127,9 +126,8 @@ class TestDHCPAgentHostingNetwork(base.TestCase):
         self.assertEqual('networks', net.resources_key)
         self.assertEqual('/agents/%(agent_id)s/dhcp-networks', net.base_path)
         self.assertEqual('dhcp-network', net.resource_name)
-        self.assertEqual('network', net.service.service_type)
         self.assertFalse(net.allow_create)
-        self.assertTrue(net.allow_get)
-        self.assertFalse(net.allow_update)
+        self.assertTrue(net.allow_fetch)
+        self.assertFalse(net.allow_commit)
         self.assertFalse(net.allow_delete)
         self.assertTrue(net.allow_list)
