@@ -10,17 +10,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.tests.unit import base
-
 from openstack.network.v2 import quota
 from openstack import resource
+from openstack.tests.unit import base
+
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
     'floatingip': 1,
     'network': 2,
     'port': 3,
-    'tenant_id': '4',
+    'project_id': '4',
     'router': 5,
     'subnet': 6,
     'subnetpool': 7,
@@ -32,6 +32,7 @@ EXAMPLE = {
     'loadbalancer': 13,
     'l7policy': 14,
     'pool': 15,
+    'check_limit': True,
 }
 
 
@@ -42,10 +43,9 @@ class TestQuota(base.TestCase):
         self.assertEqual('quota', sot.resource_key)
         self.assertEqual('quotas', sot.resources_key)
         self.assertEqual('/quotas', sot.base_path)
-        self.assertEqual('network', sot.service.service_type)
         self.assertFalse(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
@@ -54,7 +54,7 @@ class TestQuota(base.TestCase):
         self.assertEqual(EXAMPLE['floatingip'], sot.floating_ips)
         self.assertEqual(EXAMPLE['network'], sot.networks)
         self.assertEqual(EXAMPLE['port'], sot.ports)
-        self.assertEqual(EXAMPLE['tenant_id'], sot.project_id)
+        self.assertEqual(EXAMPLE['project_id'], sot.project_id)
         self.assertEqual(EXAMPLE['router'], sot.routers)
         self.assertEqual(EXAMPLE['subnet'], sot.subnets)
         self.assertEqual(EXAMPLE['subnetpool'], sot.subnet_pools)
@@ -67,6 +67,7 @@ class TestQuota(base.TestCase):
         self.assertEqual(EXAMPLE['loadbalancer'], sot.load_balancers)
         self.assertEqual(EXAMPLE['l7policy'], sot.l7_policies)
         self.assertEqual(EXAMPLE['pool'], sot.pools)
+        self.assertEqual(EXAMPLE['check_limit'], sot.check_limit)
 
     def test_prepare_request(self):
         body = {'id': 'ABCDEFGH', 'network': '12345'}
@@ -75,10 +76,10 @@ class TestQuota(base.TestCase):
         self.assertNotIn('id', response)
 
     def test_alternate_id(self):
-        my_tenant_id = 'my-tenant-id'
-        body = {'tenant_id': my_tenant_id, 'network': 12345}
+        my_project_id = 'my-tenant-id'
+        body = {'project_id': my_project_id, 'network': 12345}
         quota_obj = quota.Quota(**body)
-        self.assertEqual(my_tenant_id,
+        self.assertEqual(my_project_id,
                          resource.Resource._get_id(quota_obj))
 
 
@@ -89,10 +90,9 @@ class TestQuotaDefault(base.TestCase):
         self.assertEqual('quota', sot.resource_key)
         self.assertEqual('quotas', sot.resources_key)
         self.assertEqual('/quotas/%(project)s/default', sot.base_path)
-        self.assertEqual('network', sot.service.service_type)
         self.assertFalse(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertFalse(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertFalse(sot.allow_commit)
         self.assertFalse(sot.allow_delete)
         self.assertFalse(sot.allow_list)
 
@@ -101,7 +101,7 @@ class TestQuotaDefault(base.TestCase):
         self.assertEqual(EXAMPLE['floatingip'], sot.floating_ips)
         self.assertEqual(EXAMPLE['network'], sot.networks)
         self.assertEqual(EXAMPLE['port'], sot.ports)
-        self.assertEqual(EXAMPLE['tenant_id'], sot.project_id)
+        self.assertEqual(EXAMPLE['project_id'], sot.project_id)
         self.assertEqual(EXAMPLE['router'], sot.routers)
         self.assertEqual(EXAMPLE['subnet'], sot.subnets)
         self.assertEqual(EXAMPLE['subnetpool'], sot.subnet_pools)
@@ -114,4 +114,5 @@ class TestQuotaDefault(base.TestCase):
         self.assertEqual(EXAMPLE['loadbalancer'], sot.load_balancers)
         self.assertEqual(EXAMPLE['l7policy'], sot.l7_policies)
         self.assertEqual(EXAMPLE['pool'], sot.pools)
+        self.assertEqual(EXAMPLE['check_limit'], sot.check_limit)
         self.assertEqual('FAKE_PROJECT', sot.project)
