@@ -10,9 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.tests.unit import base
-
 from openstack.object_store.v1 import account
+from openstack.tests.unit import base
 
 
 CONTAINER_NAME = "mycontainer"
@@ -31,15 +30,18 @@ ACCOUNT_EXAMPLE = {
 
 class TestAccount(base.TestCase):
 
+    def setUp(self):
+        super(TestAccount, self).setUp()
+        self.endpoint = self.cloud.object_store.get_endpoint() + '/'
+
     def test_basic(self):
         sot = account.Account(**ACCOUNT_EXAMPLE)
         self.assertIsNone(sot.resources_key)
         self.assertIsNone(sot.id)
         self.assertEqual('/', sot.base_path)
-        self.assertEqual('object-store', sot.service.service_type)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_head)
-        self.assertTrue(sot.allow_get)
+        self.assertTrue(sot.allow_fetch)
         self.assertFalse(sot.allow_delete)
         self.assertFalse(sot.allow_list)
         self.assertFalse(sot.allow_create)
@@ -54,3 +56,37 @@ class TestAccount(base.TestCase):
         self.assertEqual(int(ACCOUNT_EXAMPLE['x-account-object-count']),
                          sot.account_object_count)
         self.assertEqual(ACCOUNT_EXAMPLE['x-timestamp'], sot.timestamp)
+
+    def test_set_temp_url_key(self):
+        sot = account.Account()
+        key = 'super-secure-key'
+
+        self.register_uris([
+            dict(method='POST', uri=self.endpoint,
+                 status_code=204,
+                 validate=dict(
+                     headers={
+                         'x-account-meta-temp-url-key': key})),
+            dict(method='HEAD', uri=self.endpoint,
+                 headers={
+                     'x-account-meta-temp-url-key': key}),
+        ])
+        sot.set_temp_url_key(self.cloud.object_store, key)
+        self.assert_calls()
+
+    def test_set_account_temp_url_key_second(self):
+        sot = account.Account()
+        key = 'super-secure-key'
+
+        self.register_uris([
+            dict(method='POST', uri=self.endpoint,
+                 status_code=204,
+                 validate=dict(
+                     headers={
+                         'x-account-meta-temp-url-key-2': key})),
+            dict(method='HEAD', uri=self.endpoint,
+                 headers={
+                     'x-account-meta-temp-url-key-2': key}),
+        ])
+        sot.set_temp_url_key(self.cloud.object_store, key, secondary=True)
+        self.assert_calls()
